@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 /*
  * TODO:
  * - manage I/O pipes (several ones, and stdin)
@@ -82,7 +78,7 @@ struct _Ecore_Exe
    Eina_Bool    close_stdin : 1;
    Eina_Bool    is_suspended : 1;
 
-   void (*pre_free_cb)(void *data, const Ecore_Exe *exe);
+   Ecore_Exe_Cb pre_free_cb;
 };
 
 static Ecore_Exe *exes = NULL;
@@ -292,7 +288,7 @@ ecore_exe_pipe_run(const char *exe_cmd, Ecore_Exe_Flags flags, const void *data)
 }
 
 EAPI void
-ecore_exe_callback_pre_free_set(Ecore_Exe *exe, void (*func)(void *data, const Ecore_Exe *exe))
+ecore_exe_callback_pre_free_set(Ecore_Exe *exe, Ecore_Exe_Cb func)
 {
    if (!ECORE_MAGIC_CHECK(exe, ECORE_MAGIC_EXE))
      {
@@ -329,7 +325,7 @@ ecore_exe_send(Ecore_Exe *exe, const void *data, int size)
      }
 
    buf = realloc(exe->pipe_write.data_buf, exe->pipe_write.data_size + size);
-   if (buf == NULL) return 0;
+   if (!buf) return 0;
 
    exe->pipe_write.data_buf = buf;
    memcpy((char *)exe->pipe_write.data_buf + exe->pipe_write.data_size, data, size);
@@ -625,7 +621,7 @@ ecore_exe_hup(Ecore_Exe *exe)
 static int
 _ecore_exe_win32_pipe_thread_generic_cb(void *data, Ecore_Exe_Flags flags)
 {
-#define BUFSIZE 2
+#define BUFSIZE 2048
    char        buf[BUFSIZE];
    Ecore_Exe  *exe;
    char       *current_buf = NULL;
@@ -657,7 +653,7 @@ _ecore_exe_win32_pipe_thread_generic_cb(void *data, Ecore_Exe_Flags flags)
 
    while (1)
      {
-        if (!PeekNamedPipe(child_pipe, buf, 1, &size, &current_size, NULL))
+       if (!PeekNamedPipe(child_pipe, buf, sizeof(buf), &size, &current_size, NULL))
           continue;
         if (size == 0)
           continue;
