@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -106,23 +102,23 @@ _ecore_signal_shutdown(void)
 #ifdef SIGRTMIN
    for (i = 0; i < num; i++)
      {
-	_ecore_signal_callback_set(SIGRTMIN + i, (Signal_Handler) SIG_DFL);
-	sigrt_count[i] = 0;
+        _ecore_signal_callback_set(SIGRTMIN + i, (Signal_Handler) SIG_DFL);
+        sigrt_count[i] = 0;
      }
 
    if (sigrt_count)
      {
-	free((sig_atomic_t *) sigrt_count);
-	sigrt_count = NULL;
+        free((sig_atomic_t *) sigrt_count);
+        sigrt_count = NULL;
      }
 
    for (i = 0; i < MAXSIGQ; i++)
      {
-	if (sigrt_info[i])
-	  {
-	     free((siginfo_t *) sigrt_info[i]);
-	     sigrt_info[i] = NULL;
-	  }
+        if (sigrt_info[i])
+          {
+             free((siginfo_t *) sigrt_info[i]);
+             sigrt_info[i] = NULL;
+          }
      }
 #endif
 }
@@ -153,8 +149,8 @@ _ecore_signal_init(void)
 
    for (i = 0; i < MAXSIGQ; i++)
      {
-	sigrt_info[i] = calloc(1, sizeof(siginfo_t) * num);
-	assert(sigrt_info[i]);
+        sigrt_info[i] = calloc(1, sizeof(siginfo_t) * num);
+        assert(sigrt_info[i]);
      }
 
    for (i = 0; i < num; i++)
@@ -198,220 +194,220 @@ _ecore_signal_call(void)
    sigprocmask(SIG_BLOCK, &newset, &oldset);
    if (sigchld_count > MAXSIGQ)
      WRN("%i SIGCHLD in queue. max queue size %i. losing "
-	  "siginfo for extra signals.", sigchld_count, MAXSIGQ);
+          "siginfo for extra signals.", sigchld_count, MAXSIGQ);
    for (n = 0; n < sigchld_count; n++)
      {
-	pid_t pid;
-	int status;
+        pid_t pid;
+        int status;
 
-	while ((pid = waitpid(-1, &status, WNOHANG)) > 0)
-	  {
-	     Ecore_Exe_Event_Del *e;
+        while ((pid = waitpid(-1, &status, WNOHANG)) > 0)
+          {
+             Ecore_Exe_Event_Del *e;
 
-	     /* FIXME: If this process is set respawn, respawn with a suitable backoff
-	      * period for those that need too much respawning.
-	      */
-	     e = _ecore_exe_event_del_new();
-	     if (e)
-	       {
-		  if (WIFEXITED(status))
-		    {
-		       e->exit_code = WEXITSTATUS(status);
-		       e->exited = 1;
-		    }
-		  else if (WIFSIGNALED(status))
-		    {
-		       e->exit_signal = WTERMSIG(status);
-		       e->signalled = 1;
-		    }
-		  e->pid = pid;
-		  e->exe = _ecore_exe_find(pid);
+             /* FIXME: If this process is set respawn, respawn with a suitable backoff
+              * period for those that need too much respawning.
+              */
+             e = _ecore_exe_event_del_new();
+             if (e)
+               {
+                  if (WIFEXITED(status))
+                    {
+                       e->exit_code = WEXITSTATUS(status);
+                       e->exited = 1;
+                    }
+                  else if (WIFSIGNALED(status))
+                    {
+                       e->exit_signal = WTERMSIG(status);
+                       e->signalled = 1;
+                    }
+                  e->pid = pid;
+                  e->exe = _ecore_exe_find(pid);
 
-		  if ((n < MAXSIGQ) && (sigchld_info[n].si_signo))
-		    e->data = sigchld_info[n]; /* No need to clone this. */
+                  if ((n < MAXSIGQ) && (sigchld_info[n].si_signo))
+                    e->data = sigchld_info[n]; /* No need to clone this. */
 
                   if ((e->exe) && (ecore_exe_flags_get(e->exe) & (ECORE_EXE_PIPE_READ | ECORE_EXE_PIPE_ERROR)))
                      {
-		        /* We want to report the Last Words of the exe, so delay this event.
-			 * This is twice as relevant for stderr.
-			 * There are three possibilities here -
-			 *  1 There are no Last Words.
-			 *  2 There are Last Words, they are not ready to be read.
-			 *  3 There are Last Words, they are ready to be read.
-			 *
-			 * For 1 we don't want to delay, for 3 we want to delay.
-			 * 2 is the problem.  If we check for data now and there
-			 * is none, then there is no way to differentiate 1 and 2.
-			 * If we don't delay, we may loose data, but if we do delay,
-			 * there may not be data and the exit event never gets sent.
-			 *
-			 * Any way you look at it, there has to be some time passed
-			 * before the exit event gets sent.  So the strategy here is
-			 * to setup a timer event that will send the exit event after
-			 * an arbitrary, but brief, time.
-			 *
-			 * This is probably paranoid, for the less paraniod, we could
-			 * check to see for Last Words, and only delay if there are any.
-			 * This has it's own set of problems.
-			 */
+                        /* We want to report the Last Words of the exe, so delay this event.
+                         * This is twice as relevant for stderr.
+                         * There are three possibilities here -
+                         *  1 There are no Last Words.
+                         *  2 There are Last Words, they are not ready to be read.
+                         *  3 There are Last Words, they are ready to be read.
+                         *
+                         * For 1 we don't want to delay, for 3 we want to delay.
+                         * 2 is the problem.  If we check for data now and there
+                         * is none, then there is no way to differentiate 1 and 2.
+                         * If we don't delay, we may loose data, but if we do delay,
+                         * there may not be data and the exit event never gets sent.
+                         *
+                         * Any way you look at it, there has to be some time passed
+                         * before the exit event gets sent.  So the strategy here is
+                         * to setup a timer event that will send the exit event after
+                         * an arbitrary, but brief, time.
+                         *
+                         * This is probably paranoid, for the less paraniod, we could
+                         * check to see for Last Words, and only delay if there are any.
+                         * This has it's own set of problems.
+                         */
                         Ecore_Timer *doomsday_clock;
 
                         doomsday_clock = _ecore_exe_doomsday_clock_get(e->exe);
                         IF_FN_DEL(ecore_timer_del, doomsday_clock);
                         _ecore_exe_doomsday_clock_set(e->exe, ecore_timer_add(0.1, _ecore_signal_exe_exit_delay, e));
                      }
-		  else
-		    {
-		       _ecore_event_add(ECORE_EXE_EVENT_DEL, e,
-				   _ecore_exe_event_del_free, NULL);
-		    }
-	       }
-	  }
-	sig_count--;
+                  else
+                    {
+                       _ecore_event_add(ECORE_EXE_EVENT_DEL, e,
+                                   _ecore_exe_event_del_free, NULL);
+                    }
+               }
+          }
+        sig_count--;
      }
    sigchld_count = 0;
 
    if (sigusr1_count > MAXSIGQ)
      WRN("%i SIGUSR1 in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sigusr1_count, MAXSIGQ);
+         "siginfo for extra signals.", sigusr1_count, MAXSIGQ);
    for (n = 0; n < sigusr1_count; n++)
      {
-	Ecore_Event_Signal_User *e;
+        Ecore_Event_Signal_User *e;
 
-	e = _ecore_event_signal_user_new();
-	if (e)
-	  {
-	     e->number = 1;
+        e = _ecore_event_signal_user_new();
+        if (e)
+          {
+             e->number = 1;
 
-	     if ((n < MAXSIGQ) && (sigusr1_info[n].si_signo))
-	       e->data = sigusr1_info[n];
+             if ((n < MAXSIGQ) && (sigusr1_info[n].si_signo))
+               e->data = sigusr1_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_USER, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_USER, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sigusr1_count = 0;
 
    if (sigusr2_count > MAXSIGQ)
      WRN("%i SIGUSR2 in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sigusr2_count, MAXSIGQ);
+         "siginfo for extra signals.", sigusr2_count, MAXSIGQ);
    for (n = 0; n < sigusr2_count; n++)
      {
-	Ecore_Event_Signal_User *e;
+        Ecore_Event_Signal_User *e;
 
-	e = _ecore_event_signal_user_new();
-	if (e)
-	  {
-	     e->number = 2;
+        e = _ecore_event_signal_user_new();
+        if (e)
+          {
+             e->number = 2;
 
-	     if ((n < MAXSIGQ) && (sigusr2_info[n].si_signo))
-	       e->data = sigusr2_info[n];
+             if ((n < MAXSIGQ) && (sigusr2_info[n].si_signo))
+               e->data = sigusr2_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_USER, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_USER, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sigusr2_count = 0;
 
    if (sighup_count > MAXSIGQ)
      WRN("%i SIGHUP in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sighup_count, MAXSIGQ);
+         "siginfo for extra signals.", sighup_count, MAXSIGQ);
    for (n = 0; n < sighup_count; n++)
      {
-	Ecore_Event_Signal_Hup *e;
+        Ecore_Event_Signal_Hup *e;
 
-	e = _ecore_event_signal_hup_new();
-	if (e)
-	  {
-	     if ((n < MAXSIGQ) && (sighup_info[n].si_signo))
-	       e->data = sighup_info[n];
+        e = _ecore_event_signal_hup_new();
+        if (e)
+          {
+             if ((n < MAXSIGQ) && (sighup_info[n].si_signo))
+               e->data = sighup_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_HUP, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_HUP, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sighup_count = 0;
 
    if (sigquit_count > MAXSIGQ)
      WRN("%i SIGQUIT in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sigquit_count, MAXSIGQ);
+         "siginfo for extra signals.", sigquit_count, MAXSIGQ);
    for (n = 0; n < sigquit_count; n++)
      {
-	Ecore_Event_Signal_Exit *e;
+        Ecore_Event_Signal_Exit *e;
 
-	e = _ecore_event_signal_exit_new();
-	if (e)
-	  {
-	     e->quit = 1;
+        e = _ecore_event_signal_exit_new();
+        if (e)
+          {
+             e->quit = 1;
 
-	     if ((n < MAXSIGQ) && (sigquit_info[n].si_signo))
-	       e->data = sigquit_info[n];
+             if ((n < MAXSIGQ) && (sigquit_info[n].si_signo))
+               e->data = sigquit_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sigquit_count = 0;
 
    if (sigint_count > MAXSIGQ)
      WRN("%i SIGINT in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sigint_count, MAXSIGQ);
+         "siginfo for extra signals.", sigint_count, MAXSIGQ);
    for (n = 0; n < sigint_count; n++)
      {
-	Ecore_Event_Signal_Exit *e;
+        Ecore_Event_Signal_Exit *e;
 
-	e = _ecore_event_signal_exit_new();
-	if (e)
-	  {
-	     e->interrupt = 1;
+        e = _ecore_event_signal_exit_new();
+        if (e)
+          {
+             e->interrupt = 1;
 
-	     if ((n < MAXSIGQ) && (sigint_info[n].si_signo))
-	       e->data = sigint_info[n];
+             if ((n < MAXSIGQ) && (sigint_info[n].si_signo))
+               e->data = sigint_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sigint_count = 0;
 
    if (sigterm_count > MAXSIGQ)
      WRN("%i SIGTERM in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sigterm_count, MAXSIGQ);
+         "siginfo for extra signals.", sigterm_count, MAXSIGQ);
    for (n = 0; n < sigterm_count; n++)
      {
-	Ecore_Event_Signal_Exit *e;
+        Ecore_Event_Signal_Exit *e;
 
-	e = _ecore_event_signal_exit_new();
-	if (e)
-	  {
-	     e->terminate = 1;
+        e = _ecore_event_signal_exit_new();
+        if (e)
+          {
+             e->terminate = 1;
 
-	     if ((n < MAXSIGQ) && (sigterm_info[n].si_signo))
-	       e->data = sigterm_info[n];
+             if ((n < MAXSIGQ) && (sigterm_info[n].si_signo))
+               e->data = sigterm_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sigterm_count = 0;
 
 #ifdef SIGPWR
    if (sigpwr_count > MAXSIGQ)
      WRN("%i SIGPWR in queue. max queue size %i. losing "
-	 "siginfo for extra signals.", sigpwr_count, MAXSIGQ);
+         "siginfo for extra signals.", sigpwr_count, MAXSIGQ);
    for (n = 0; n < sigpwr_count; n++)
      {
-	Ecore_Event_Signal_Power *e;
+        Ecore_Event_Signal_Power *e;
 
-	e = _ecore_event_signal_power_new();
-	if (e)
-	  {
-	     if ((n < MAXSIGQ) && (sigpwr_info[n].si_signo))
-	       e->data = sigpwr_info[n];
+        e = _ecore_event_signal_power_new();
+        if (e)
+          {
+             if ((n < MAXSIGQ) && (sigpwr_info[n].si_signo))
+               e->data = sigpwr_info[n];
 
-	     ecore_event_add(ECORE_EVENT_SIGNAL_POWER, e, NULL, NULL);
-	  }
-	sig_count--;
+             ecore_event_add(ECORE_EVENT_SIGNAL_POWER, e, NULL, NULL);
+          }
+        sig_count--;
      }
    sigpwr_count = 0;
 #endif
@@ -419,25 +415,25 @@ _ecore_signal_call(void)
 #ifdef SIGRTMIN
    for (i = 0; i < num; i++)
      {
-	if (sigrt_count[i] > MAXSIGQ)
-	  WRN("%i SIGRT%i in queue. max queue size %i. losing "
-	      "siginfo for extra signals.", i + 1, sigrt_count[i], MAXSIGQ);
-	for (n = 0; n < sigrt_count[i]; n++)
-	  {
-	     Ecore_Event_Signal_Realtime *e;
+        if (sigrt_count[i] > MAXSIGQ)
+          WRN("%i SIGRT%i in queue. max queue size %i. losing "
+              "siginfo for extra signals.", i + 1, sigrt_count[i], MAXSIGQ);
+        for (n = 0; n < sigrt_count[i]; n++)
+          {
+             Ecore_Event_Signal_Realtime *e;
 
-	     if ((e = _ecore_event_signal_realtime_new()))
-	       {
-		  e->num = i;
+             if ((e = _ecore_event_signal_realtime_new()))
+               {
+                  e->num = i;
 
-		  if ((n < MAXSIGQ) && (sigrt_info[n][i].si_signo))
-		    e->data = sigrt_info[n][i];
+                  if ((n < MAXSIGQ) && (sigrt_info[n][i].si_signo))
+                    e->data = sigrt_info[n][i];
 
-		  ecore_event_add(ECORE_EVENT_SIGNAL_REALTIME, e, NULL, NULL);
-	       }
-	     sig_count--;
-	  }
-	sigrt_count[i] = 0;
+                  ecore_event_add(ECORE_EVENT_SIGNAL_REALTIME, e, NULL, NULL);
+               }
+             sig_count--;
+          }
+        sigrt_count[i] = 0;
      }
 #endif
    sigprocmask(SIG_SETMASK, &oldset, NULL);
@@ -466,10 +462,10 @@ _ecore_signal_callback_sigchld(int sig __UNUSED__, siginfo_t *si, void *foo __UN
    n = sigchld_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigchld_info[n] = *si;
-	else
-	  sigchld_info[n].si_signo = 0;
+        if (si)
+          sigchld_info[n] = *si;
+        else
+          sigchld_info[n].si_signo = 0;
      }
 
    sigchld_count++;
@@ -480,13 +476,13 @@ static void
 _ecore_signal_callback_sigusr1(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigusr1_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigusr1_info[n] = *si;
-	else
-	  sigusr1_info[n].si_signo = 0;
+        if (si)
+          sigusr1_info[n] = *si;
+        else
+          sigusr1_info[n].si_signo = 0;
      }
    sigusr1_count++;
    sig_count++;
@@ -496,13 +492,13 @@ static void
 _ecore_signal_callback_sigusr2(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigusr2_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigusr2_info[n] = *si;
-	else
-	  sigusr2_info[n].si_signo = 0;
+        if (si)
+          sigusr2_info[n] = *si;
+        else
+          sigusr2_info[n].si_signo = 0;
      }
    sigusr2_count++;
    sig_count++;
@@ -512,13 +508,13 @@ static void
 _ecore_signal_callback_sighup(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sighup_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sighup_info[n] = *si;
-	else
-	  sighup_info[n].si_signo = 0;
+        if (si)
+          sighup_info[n] = *si;
+        else
+          sighup_info[n].si_signo = 0;
      }
    sighup_count++;
    sig_count++;
@@ -528,13 +524,13 @@ static void
 _ecore_signal_callback_sigquit(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigquit_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigquit_info[n] = *si;
-	else
-	  sigquit_info[n].si_signo = 0;
+        if (si)
+          sigquit_info[n] = *si;
+        else
+          sigquit_info[n].si_signo = 0;
      }
    sigquit_count++;
    sig_count++;
@@ -544,13 +540,13 @@ static void
 _ecore_signal_callback_sigint(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigint_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigint_info[n] = *si;
-	else
-	  sigint_info[n].si_signo = 0;
+        if (si)
+          sigint_info[n] = *si;
+        else
+          sigint_info[n].si_signo = 0;
      }
    sigint_count++;
    sig_count++;
@@ -560,13 +556,13 @@ static void
 _ecore_signal_callback_sigterm(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigterm_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigterm_info[n] = *si;
-	else
-	  sigterm_info[n].si_signo = 0;
+        if (si)
+          sigterm_info[n] = *si;
+        else
+          sigterm_info[n].si_signo = 0;
      }
    sigterm_count++;
    sig_count++;
@@ -577,13 +573,13 @@ static void
 _ecore_signal_callback_sigpwr(int sig __UNUSED__, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigpwr_count;
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigpwr_info[n] = *si;
-	else
-	  sigpwr_info[n].si_signo = 0;
+        if (si)
+          sigpwr_info[n] = *si;
+        else
+          sigpwr_info[n].si_signo = 0;
      }
    sigpwr_count++;
    sig_count++;
@@ -595,13 +591,13 @@ static void
 _ecore_signal_callback_sigrt(int sig, siginfo_t *si, void *foo __UNUSED__)
 {
    volatile sig_atomic_t n;
-   n = sigchld_count;
+   n = sigrt_count[sig - SIGRTMIN];
    if (n < MAXSIGQ)
      {
-	if (si)
-	  sigrt_info[n][sig - SIGRTMIN] = *si;
-	else
-	  sigrt_info[n][sig - SIGRTMIN].si_signo = 0;
+        if (si)
+          sigrt_info[n][sig - SIGRTMIN] = *si;
+        else
+          sigrt_info[n][sig - SIGRTMIN].si_signo = 0;
      }
    sigrt_count[sig - SIGRTMIN]++;
    sig_count++;
@@ -616,9 +612,9 @@ _ecore_signal_exe_exit_delay(void *data)
    e = data;
    if (e)
      {
-	_ecore_exe_doomsday_clock_set(e->exe, NULL);
-	_ecore_event_add(ECORE_EXE_EVENT_DEL, e,
-			 _ecore_exe_event_del_free, NULL);
+        _ecore_exe_doomsday_clock_set(e->exe, NULL);
+        _ecore_event_add(ECORE_EXE_EVENT_DEL, e,
+                         _ecore_exe_event_del_free, NULL);
      }
    return ECORE_CALLBACK_CANCEL;
 }
