@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -20,7 +16,7 @@ struct _Ecore_Timer
    double          in;
    double          at;
    double          pending;
-   Eina_Bool     (*func) (void *data);
+   Ecore_Task_Cb   func;
    void           *data;
 
    int             references;
@@ -30,7 +26,7 @@ struct _Ecore_Timer
 };
 
 
-static void _ecore_timer_set(Ecore_Timer *timer, double at, double in, Eina_Bool (*func) (void *data), void *data);
+static void _ecore_timer_set(Ecore_Timer *timer, double at, double in, Ecore_Task_Cb func, void *data);
 
 static int          timers_added = 0;
 static int          timers_delete_me = 0;
@@ -41,10 +37,20 @@ static double       last_check = 0.0;
 static double       precision = 10.0 / 1000000.0;
 
 /**
- * @defgroup Ecore_Time_Group Ecore Time Functions
+ * @addtogroup Ecore_Group Ecore - Main Loop and Job Functions.
+ *
+ * @{
+ */
+
+/**
+ * @addtogroup Ecore_Time_Group Ecore Time functions
  *
  * Functions that deal with time.  These functions include those that simply
  * retrieve it in a given format, and those that create events based on it.
+ *
+ * The timer allows callbacks to be called at specific intervals.
+ *
+ * @{
  */
 
 /**
@@ -87,8 +93,8 @@ ecore_timer_precision_set(double value)
 {
    if (value < 0.0)
      {
-	ERR("Precision %f less than zero, ignored", value);
-	return;
+        ERR("Precision %f less than zero, ignored", value);
+        return;
      }
    precision = value;
 }
@@ -100,7 +106,6 @@ ecore_timer_precision_set(double value)
  *               rescheduled for the next interval @p in.
  * @param   data Data to pass to @p func when it is called.
  * @return  A timer object on success.  @c NULL on failure.
- * @ingroup Ecore_Time_Group
  *
  * This function adds a timer and returns its handle on success and NULL on
  * failure. The function @p func will be called every @p in seconds. The
@@ -113,7 +118,7 @@ ecore_timer_precision_set(double value)
  * invalid.
  */
 EAPI Ecore_Timer *
-ecore_timer_add(double in, Eina_Bool (*func) (void *data), const void *data)
+ecore_timer_add(double in, Ecore_Task_Cb func, const void *data)
 {
    double now;
    Ecore_Timer *timer;
@@ -135,14 +140,13 @@ ecore_timer_add(double in, Eina_Bool (*func) (void *data), const void *data)
  *               rescheduled for the next interval @p in.
  * @param   data Data to pass to @p func when it is called.
  * @return  A timer object on success.  @c NULL on failure.
- * @ingroup Ecore_Time_Group
  *
  * This is the same as ecore_timer_add(), but "now" is the time from
  * ecore_loop_time_get() not ecore_time_get() as ecore_timer_add() uses. See
  * ecore_timer_add() for more details.
  */
 EAPI Ecore_Timer *
-ecore_timer_loop_add(double in, Eina_Bool (*func) (void *data), const void *data)
+ecore_timer_loop_add(double in, Ecore_Task_Cb func, const void *data)
 {
    double now;
    Ecore_Timer *timer;
@@ -162,7 +166,6 @@ ecore_timer_loop_add(double in, Eina_Bool (*func) (void *data), const void *data
  * @param   timer The timer to delete.
  * @return  The data pointer set for the timer when @ref ecore_timer_add was
  *          called.  @c NULL is returned if the function is unsuccessful.
- * @ingroup Ecore_Time_Group
  *
  * Note: @p timer must be a valid handle. If the timer function has already
  * returned 0, the handle is no longer valid (and does not need to be delete).
@@ -172,27 +175,27 @@ ecore_timer_del(Ecore_Timer *timer)
 {
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
-			 "ecore_timer_del");
-	return NULL;
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+                         "ecore_timer_del");
+        return NULL;
      }
 
    if (timer->frozen && !timer->references)
      {
-	void *data = timer->data;
+        void *data = timer->data;
 
-	suspended = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(suspended), EINA_INLIST_GET(timer));
+        suspended = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(suspended), EINA_INLIST_GET(timer));
 
-	if (timer->delete_me)
-	  timers_delete_me--;
+        if (timer->delete_me)
+          timers_delete_me--;
 
-	free(timer);
-	return data;
+        free(timer);
+        return data;
      }
 
-   if (timer->delete_me) return timer->data;
-   timers_delete_me++;
+   EINA_SAFETY_ON_TRUE_RETURN_VAL(timer->delete_me, NULL);
    timer->delete_me = 1;
+   timers_delete_me++;
    return timer->data;
 }
 
@@ -202,16 +205,15 @@ ecore_timer_del(Ecore_Timer *timer)
  *
  * @param   timer The timer to change.
  * @param   in    The interval in seconds.
- * @ingroup Ecore_Time_Group
  */
 EAPI void
 ecore_timer_interval_set(Ecore_Timer *timer, double in)
 {
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
-			 "ecore_timer_interval_set");
-	return;
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+                         "ecore_timer_interval_set");
+        return;
      }
    timer->in = in;
 }
@@ -221,66 +223,64 @@ ecore_timer_interval_set(Ecore_Timer *timer, double in)
  *
  * @param   timer The timer to retrieve the interval from
  * @return  The interval on success. -1 on failure.
- * @ingroup Ecore_Time_Group
  */
 EAPI double
 ecore_timer_interval_get(Ecore_Timer *timer)
 {
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
-			 "ecore_timer_interval_get");
-	return -1.0;
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+                         "ecore_timer_interval_get");
+        return -1.0;
      }
 
    return timer->in;
 }
 
 /**
- * Add some delay for the next occurence of a timer.
+ * Add some delay for the next occurrence of a timer.
  * This doesn't affect the interval of a timer.
  *
  * @param   timer The timer to change.
  * @param   add   The dalay to add to the next iteration.
- * @ingroup Ecore_Time_Group
  */
 EAPI void
 ecore_timer_delay(Ecore_Timer *timer, double add)
 {
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
-			 "ecore_timer_delay");
-	return;
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+                         "ecore_timer_delay");
+        return;
      }
 
    if (timer->frozen)
      {
-	timer->pending += add;
+        timer->pending += add;
      }
    else
      {
-	timers = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer));
-	_ecore_timer_set(timer, timer->at + add, timer->in, timer->func, timer->data);
+        timers = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer));
+        _ecore_timer_set(timer, timer->at + add, timer->in, timer->func, timer->data);
      }
 }
 
 /**
  * Get the pending time regarding a timer.
  *
- * @param	timer The timer to learn from.
- * @ingroup	Ecore_Time_Group
+ * @param        timer The timer to learn from.
+ * @ingroup        Ecore_Time_Group
  */
 EAPI double
 ecore_timer_pending_get(Ecore_Timer *timer)
 {
-   double	now;
+   double        now;
 
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
-			 "ecore_timer_pending_get");
-	return 0;
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+                         "ecore_timer_pending_get");
+        return 0;
      }
 
    now = ecore_time_get();
@@ -301,7 +301,7 @@ ecore_timer_freeze(Ecore_Timer *timer)
 
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
                          "ecore_timer_freeze");
         return ;
      }
@@ -327,7 +327,7 @@ ecore_timer_thaw(Ecore_Timer *timer)
 
    if (!ECORE_MAGIC_CHECK(timer, ECORE_MAGIC_TIMER))
      {
-	ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
+        ECORE_MAGIC_FAIL(timer, ECORE_MAGIC_TIMER,
                          "ecore_timer_thaw");
         return ;
      }
@@ -342,6 +342,14 @@ ecore_timer_thaw(Ecore_Timer *timer)
    _ecore_timer_set(timer, timer->pending + now, timer->in, timer->func, timer->data);
 }
 
+/**
+ * @}
+ */
+
+/**
+ * @}
+ */
+
 void
 _ecore_timer_shutdown(void)
 {
@@ -349,9 +357,9 @@ _ecore_timer_shutdown(void)
 
    while ((timer = timers))
      {
-	timers = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(timers), EINA_INLIST_GET(timers));
-	ECORE_MAGIC_SET(timer, ECORE_MAGIC_NONE);
-	free(timer);
+        timers = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(timers), EINA_INLIST_GET(timers));
+        ECORE_MAGIC_SET(timer, ECORE_MAGIC_NONE);
+        free(timer);
      }
 
    while ((timer = suspended))
@@ -368,53 +376,57 @@ void
 _ecore_timer_cleanup(void)
 {
    Ecore_Timer *l;
-   int in_use = 0;
+   int in_use = 0, todo = timers_delete_me, done = 0;
 
    if (!timers_delete_me) return;
    for (l = timers; l;)
      {
-	Ecore_Timer *timer = l;
+        Ecore_Timer *timer = l;
 
-	l = (Ecore_Timer *) EINA_INLIST_GET(l)->next;
-	if (timer->delete_me)
-	  {
-	     if (timer->references)
-	       {
-		  in_use++;
-		  continue;
-	       }
-	     timers = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer));
-	     ECORE_MAGIC_SET(timer, ECORE_MAGIC_NONE);
-	     free(timer);
-	     timers_delete_me--;
-	     if (timers_delete_me == 0) return;
-	  }
+        l = (Ecore_Timer *) EINA_INLIST_GET(l)->next;
+        if (timer->delete_me)
+          {
+             if (timer->references)
+               {
+                  in_use++;
+                  continue;
+               }
+             timers = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer));
+             ECORE_MAGIC_SET(timer, ECORE_MAGIC_NONE);
+             free(timer);
+             timers_delete_me--;
+             done++;
+             if (timers_delete_me == 0) return;
+          }
      }
    for (l = suspended; l;)
      {
-	Ecore_Timer *timer = l;
+        Ecore_Timer *timer = l;
 
-	l = (Ecore_Timer *) EINA_INLIST_GET(l)->next;
-	if (timer->delete_me)
-	  {
-	     if (timer->references)
-	       {
-		  in_use++;
-		  continue;
-	       }
-	     suspended = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(suspended), EINA_INLIST_GET(timer));
-	     ECORE_MAGIC_SET(timer, ECORE_MAGIC_NONE);
-	     free(timer);
-	     timers_delete_me--;
-	     if (timers_delete_me == 0) return;
-	  }
+        l = (Ecore_Timer *) EINA_INLIST_GET(l)->next;
+        if (timer->delete_me)
+          {
+             if (timer->references)
+               {
+                  in_use++;
+                  continue;
+               }
+             suspended = (Ecore_Timer *) eina_inlist_remove(EINA_INLIST_GET(suspended), EINA_INLIST_GET(timer));
+             ECORE_MAGIC_SET(timer, ECORE_MAGIC_NONE);
+             free(timer);
+             timers_delete_me--;
+             done++;
+             if (timers_delete_me == 0) return;
+          }
      }
 
    if ((!in_use) && (timers_delete_me))
      {
-	ERR("%d timers to delete, but they were not found! reset counter.",
-	    timers_delete_me);
-	timers_delete_me = 0;
+        ERR("%d timers to delete, but they were not found!"
+            "Stats: todo=%d, done=%d, pending=%d, in_use=%d. "
+            "reset counter.",
+            timers_delete_me, todo, done, todo - done, in_use);
+        timers_delete_me = 0;
      }
 }
 
@@ -513,55 +525,58 @@ _ecore_timer_call(double when)
    if (!timers) return 0;
    if (last_check > when)
      {
-	Ecore_Timer *timer;
-	/* User set time backwards */
-	EINA_INLIST_FOREACH(timers, timer) timer->at -= (last_check - when);
+        Ecore_Timer *timer;
+        /* User set time backwards */
+        EINA_INLIST_FOREACH(timers, timer) timer->at -= (last_check - when);
      }
    last_check = when;
 
    if (!timer_current)
      {
-	/* regular main loop, start from head */
-	timer_current = timers;
+        /* regular main loop, start from head */
+        timer_current = timers;
      }
    else
      {
-	/* recursive main loop, continue from where we were */
-	Ecore_Timer *timer_old = timer_current;
-	timer_current = (Ecore_Timer *)EINA_INLIST_GET(timer_current)->next;
-	_ecore_timer_reschedule(timer_old, when);
+        /* recursive main loop, continue from where we were */
+        Ecore_Timer *timer_old = timer_current;
+        timer_current = (Ecore_Timer *)EINA_INLIST_GET(timer_current)->next;
+        _ecore_timer_reschedule(timer_old, when);
      }
 
    while (timer_current)
      {
-	Ecore_Timer *timer = timer_current;
+        Ecore_Timer *timer = timer_current;
 
-	if (timer->at > when)
-	  {
-	     timer_current = NULL; /* ended walk, next should restart. */
-	     return 0;
-	  }
+        if (timer->at > when)
+          {
+             timer_current = NULL; /* ended walk, next should restart. */
+             return 0;
+          }
 
-	if ((timer->just_added) || (timer->delete_me))
-	  {
-	     timer_current = (Ecore_Timer*)EINA_INLIST_GET(timer_current)->next;
-	     continue;
-	  }
+        if ((timer->just_added) || (timer->delete_me))
+          {
+             timer_current = (Ecore_Timer*)EINA_INLIST_GET(timer_current)->next;
+             continue;
+          }
 
-	timer->references++;
-	if (!timer->func(timer->data)) ecore_timer_del(timer);
-	timer->references--;
+        timer->references++;
+        if (!timer->func(timer->data))
+          {
+             if (!timer->delete_me) ecore_timer_del(timer);
+          }
+        timer->references--;
 
-	if (timer_current) /* may have changed in recursive main loops */
-	  timer_current = (Ecore_Timer *)EINA_INLIST_GET(timer_current)->next;
+        if (timer_current) /* may have changed in recursive main loops */
+          timer_current = (Ecore_Timer *)EINA_INLIST_GET(timer_current)->next;
 
-	_ecore_timer_reschedule(timer, when);
+        _ecore_timer_reschedule(timer, when);
      }
    return 0;
 }
 
 static void
-_ecore_timer_set(Ecore_Timer *timer, double at, double in, Eina_Bool (*func) (void *data), void *data)
+_ecore_timer_set(Ecore_Timer *timer, double at, double in, Ecore_Task_Cb func, void *data)
 {
    Ecore_Timer *t2;
 
@@ -575,14 +590,14 @@ _ecore_timer_set(Ecore_Timer *timer, double at, double in, Eina_Bool (*func) (vo
    timer->pending = 0.0;
    if (timers)
      {
-	EINA_INLIST_REVERSE_FOREACH(EINA_INLIST_GET(timers), t2)
-	  {
-	     if (timer->at > t2->at)
-	       {
-		  timers = (Ecore_Timer *) eina_inlist_append_relative(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer), EINA_INLIST_GET(t2));
-		  return;
-	       }
-	  }
+        EINA_INLIST_REVERSE_FOREACH(EINA_INLIST_GET(timers), t2)
+          {
+             if (timer->at > t2->at)
+               {
+                  timers = (Ecore_Timer *) eina_inlist_append_relative(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer), EINA_INLIST_GET(t2));
+                  return;
+               }
+          }
      }
    timers = (Ecore_Timer *) eina_inlist_prepend(EINA_INLIST_GET(timers), EINA_INLIST_GET(timer));
 }
