@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -427,7 +423,7 @@ ecore_config_theme_search_path_append(const char *path)
    len = strlen(path);
    search_len = strlen(search_path);
    
-   if (loc == NULL || (loc != search_path && *(loc - 1) != '|') || 
+   if (!loc || (loc != search_path && *(loc - 1) != '|') || 
        (loc != (search_path + search_len - len) && *(loc + len - 1) != '|'))
      {
 	new_search_path = malloc(search_len + len + 2); /* 2 = \0 + | */
