@@ -16,7 +16,6 @@ static int
 _ecore_evas_buffer_init(void)
 {
    _ecore_evas_init_count++;
-   if (_ecore_evas_init_count > 1) return _ecore_evas_init_count;
    return _ecore_evas_init_count;
 }
 
@@ -25,15 +24,15 @@ _ecore_evas_buffer_free(Ecore_Evas *ee)
 {
    if (ee->engine.buffer.image)
      {
-	Ecore_Evas *ee2;
+        Ecore_Evas *ee2;
 
-	ee2 = evas_object_data_get(ee->engine.buffer.image, "Ecore_Evas_Parent");
-	evas_object_del(ee->engine.buffer.image);
-	ee2->sub_ecore_evas = eina_list_remove(ee2->sub_ecore_evas, ee);
+        ee2 = evas_object_data_get(ee->engine.buffer.image, "Ecore_Evas_Parent");
+        evas_object_del(ee->engine.buffer.image);
+        ee2->sub_ecore_evas = eina_list_remove(ee2->sub_ecore_evas, ee);
      }
    else
      {
-	ee->engine.buffer.free_func(ee->engine.buffer.data, 
+        ee->engine.buffer.free_func(ee->engine.buffer.data, 
                                     ee->engine.buffer.pixels);
      }
    _ecore_evas_buffer_shutdown();
@@ -43,6 +42,7 @@ static void
 _ecore_evas_resize(Ecore_Evas *ee, int w, int h)
 {
    Evas_Engine_Info_Buffer *einfo;
+   int stride = 0;
 
    if (w < 1) w = 1;
    if (h < 1) h = 1;
@@ -55,29 +55,34 @@ _ecore_evas_resize(Ecore_Evas *ee, int w, int h)
 
    if (ee->engine.buffer.image)
      {
-	ee->engine.buffer.pixels = evas_object_image_data_get(ee->engine.buffer.image, 1);
+        ee->engine.buffer.pixels = evas_object_image_data_get(ee->engine.buffer.image, 1);
+        stride = evas_object_image_stride_get(ee->engine.buffer.image);
      }
    else
      {
-	if (ee->engine.buffer.pixels)
+        if (ee->engine.buffer.pixels)
           ee->engine.buffer.free_func(ee->engine.buffer.data,
                                       ee->engine.buffer.pixels);
-	ee->engine.buffer.pixels = 
+        ee->engine.buffer.pixels = 
           ee->engine.buffer.alloc_func(ee->engine.buffer.data,
                                        ee->w * ee->h * sizeof(int));
+        stride = ee->w * sizeof(int);
      }
 
    einfo = (Evas_Engine_Info_Buffer *)evas_engine_info_get(ee->evas);
    if (einfo)
      {
-	einfo->info.depth_type = EVAS_ENGINE_BUFFER_DEPTH_ARGB32;
-	einfo->info.dest_buffer = ee->engine.buffer.pixels;
-	einfo->info.dest_buffer_row_bytes = ee->w * sizeof(int);
-	einfo->info.use_color_key = 0;
-	einfo->info.alpha_threshold = 0;
-	einfo->info.func.new_update_region = NULL;
-	einfo->info.func.free_update_region = NULL;
-	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
+        einfo->info.depth_type = EVAS_ENGINE_BUFFER_DEPTH_ARGB32;
+        einfo->info.dest_buffer = ee->engine.buffer.pixels;
+        einfo->info.dest_buffer_row_bytes = stride;
+        einfo->info.use_color_key = 0;
+        einfo->info.alpha_threshold = 0;
+        einfo->info.func.new_update_region = NULL;
+        einfo->info.func.free_update_region = NULL;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
      }
    if (ee->func.fn_resize) ee->func.fn_resize(ee);
 }
@@ -102,32 +107,31 @@ _ecore_evas_buffer_render(Ecore_Evas *ee)
 
    EINA_LIST_FOREACH(ee->sub_ecore_evas, ll, ee2)
      {
-	if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
-	rend |= _ecore_evas_buffer_render(ee2);
-	if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
+        if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
+        rend |= _ecore_evas_buffer_render(ee2);
+        if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
      }
    if (ee->engine.buffer.image)
      {
-	int w, h;
+        int w, h;
 
-	evas_object_image_size_get(ee->engine.buffer.image, &w, &h);
-	if ((w != ee->w) || (h != ee->h))
-	  _ecore_evas_resize(ee, w, h);
+        evas_object_image_size_get(ee->engine.buffer.image, &w, &h);
+        if ((w != ee->w) || (h != ee->h))
+          _ecore_evas_resize(ee, w, h);
      }
    updates = evas_render_updates(ee->evas);
    if (ee->engine.buffer.image)
      {
         Eina_Rectangle *r;
 
-	EINA_LIST_FOREACH(updates, l, r)
-	  if (ee->engine.buffer.image)
-	    evas_object_image_data_update_add(ee->engine.buffer.image,
-					      r->x, r->y, r->w, r->h);
+        EINA_LIST_FOREACH(updates, l, r)
+          evas_object_image_data_update_add(ee->engine.buffer.image,
+                                            r->x, r->y, r->w, r->h);
      }
    if (updates)
      {
-	evas_render_updates_free(updates);
-	_ecore_evas_idle_timeout_update(ee);
+        evas_render_updates_free(updates);
+        _ecore_evas_idle_timeout_update(ee);
      }
 
    return updates ? 1 : rend;
@@ -483,13 +487,13 @@ static Ecore_Evas_Engine_Func _ecore_buffer_engine_func =
 #endif
 
 static void *
-_ecore_evas_buffer_pix_alloc(void *data, int size)
+_ecore_evas_buffer_pix_alloc(void *data __UNUSED__, int size)
 {
    return malloc(size);
 }
 
 static void
-_ecore_evas_buffer_pix_free(void *data, void *pix)
+_ecore_evas_buffer_pix_free(void *data __UNUSED__, void *pix)
 {
    free(pix);
 }
@@ -563,14 +567,17 @@ ecore_evas_buffer_allocfunc_new(int w, int h, void *(*alloc_func) (void *data, i
    einfo = (Evas_Engine_Info_Buffer *)evas_engine_info_get(ee->evas);
    if (einfo)
      {
-	einfo->info.depth_type = EVAS_ENGINE_BUFFER_DEPTH_ARGB32;
-	einfo->info.dest_buffer = ee->engine.buffer.pixels;
-	einfo->info.dest_buffer_row_bytes = ee->w * sizeof(int);
-	einfo->info.use_color_key = 0;
-	einfo->info.alpha_threshold = 0;
-	einfo->info.func.new_update_region = NULL;
-	einfo->info.func.free_update_region = NULL;
-	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
+        einfo->info.depth_type = EVAS_ENGINE_BUFFER_DEPTH_ARGB32;
+        einfo->info.dest_buffer = ee->engine.buffer.pixels;
+        einfo->info.dest_buffer_row_bytes = ee->w * sizeof(int);
+        einfo->info.use_color_key = 0;
+        einfo->info.alpha_threshold = 0;
+        einfo->info.func.new_update_region = NULL;
+        einfo->info.func.free_update_region = NULL;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
      }
    evas_key_modifier_add(ee->evas, "Shift");
    evas_key_modifier_add(ee->evas, "Control");
@@ -604,6 +611,23 @@ ecore_evas_buffer_pixels_get(Ecore_Evas *ee)
 #endif
 }
 
+EAPI Evas *
+ecore_evas_object_evas_get(Evas_Object *obj)
+{
+   Ecore_Evas *ee;
+
+   ee = evas_object_data_get(obj, "Ecore_Evas");
+   if (!ee) return NULL;
+
+   return ecore_evas_get(ee);
+}
+
+EAPI Ecore_Evas *
+ecore_evas_object_ecore_evas_get(Evas_Object *obj)
+{
+   return evas_object_data_get(obj, "Ecore_Evas");
+}
+
 EAPI Evas_Object *
 ecore_evas_object_image_new(Ecore_Evas *ee_target)
 {
@@ -620,7 +644,9 @@ ecore_evas_object_image_new(Ecore_Evas *ee_target)
    if (!ee) return NULL;
 
    o = evas_object_image_add(ee_target->evas);
-
+   evas_object_image_content_hint_set(o, EVAS_IMAGE_CONTENT_HINT_DYNAMIC);
+   evas_object_image_colorspace_set(o, EVAS_COLORSPACE_ARGB8888);
+  
    ECORE_MAGIC_SET(ee, ECORE_MAGIC_EVAS);
 
    _ecore_evas_buffer_init();
@@ -662,64 +688,67 @@ ecore_evas_object_image_new(Ecore_Evas *ee_target)
    ee->engine.buffer.pixels = evas_object_image_data_get(o, 1);
    evas_object_image_data_set(o, ee->engine.buffer.pixels);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MOUSE_IN,
-				  _ecore_evas_buffer_cb_mouse_in, ee);
+                                  EVAS_CALLBACK_MOUSE_IN,
+                                  _ecore_evas_buffer_cb_mouse_in, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MOUSE_OUT,
-				  _ecore_evas_buffer_cb_mouse_out, ee);
+                                  EVAS_CALLBACK_MOUSE_OUT,
+                                  _ecore_evas_buffer_cb_mouse_out, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MOUSE_DOWN,
-				  _ecore_evas_buffer_cb_mouse_down, ee);
+                                  EVAS_CALLBACK_MOUSE_DOWN,
+                                  _ecore_evas_buffer_cb_mouse_down, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MOUSE_UP,
-				  _ecore_evas_buffer_cb_mouse_up, ee);
+                                  EVAS_CALLBACK_MOUSE_UP,
+                                  _ecore_evas_buffer_cb_mouse_up, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MOUSE_MOVE,
-				  _ecore_evas_buffer_cb_mouse_move, ee);
+                                  EVAS_CALLBACK_MOUSE_MOVE,
+                                  _ecore_evas_buffer_cb_mouse_move, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MOUSE_WHEEL,
-				  _ecore_evas_buffer_cb_mouse_wheel, ee);
+                                  EVAS_CALLBACK_MOUSE_WHEEL,
+                                  _ecore_evas_buffer_cb_mouse_wheel, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MULTI_DOWN,
-				  _ecore_evas_buffer_cb_multi_down, ee);
+                                  EVAS_CALLBACK_MULTI_DOWN,
+                                  _ecore_evas_buffer_cb_multi_down, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MULTI_UP,
-				  _ecore_evas_buffer_cb_multi_up, ee);
+                                  EVAS_CALLBACK_MULTI_UP,
+                                  _ecore_evas_buffer_cb_multi_up, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_MULTI_MOVE,
-				  _ecore_evas_buffer_cb_multi_move, ee);
+                                  EVAS_CALLBACK_MULTI_MOVE,
+                                  _ecore_evas_buffer_cb_multi_move, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_FREE,
-				  _ecore_evas_buffer_cb_free, ee);
+                                  EVAS_CALLBACK_FREE,
+                                  _ecore_evas_buffer_cb_free, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_KEY_DOWN,
-				  _ecore_evas_buffer_cb_key_down, ee);
+                                  EVAS_CALLBACK_KEY_DOWN,
+                                  _ecore_evas_buffer_cb_key_down, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_KEY_UP,
-				  _ecore_evas_buffer_cb_key_up, ee);
+                                  EVAS_CALLBACK_KEY_UP,
+                                  _ecore_evas_buffer_cb_key_up, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_FOCUS_IN,
-				  _ecore_evas_buffer_cb_focus_in, ee);
+                                  EVAS_CALLBACK_FOCUS_IN,
+                                  _ecore_evas_buffer_cb_focus_in, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_FOCUS_OUT,
-				  _ecore_evas_buffer_cb_focus_out, ee);
+                                  EVAS_CALLBACK_FOCUS_OUT,
+                                  _ecore_evas_buffer_cb_focus_out, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_SHOW,
-				  _ecore_evas_buffer_cb_show, ee);
+                                  EVAS_CALLBACK_SHOW,
+                                  _ecore_evas_buffer_cb_show, ee);
    evas_object_event_callback_add(ee->engine.buffer.image,
-				  EVAS_CALLBACK_HIDE,
-				  _ecore_evas_buffer_cb_hide, ee);
+                                  EVAS_CALLBACK_HIDE,
+                                  _ecore_evas_buffer_cb_hide, ee);
    einfo = (Evas_Engine_Info_Buffer *)evas_engine_info_get(ee->evas);
    if (einfo)
      {
-	einfo->info.depth_type = EVAS_ENGINE_BUFFER_DEPTH_ARGB32;
-	einfo->info.dest_buffer = ee->engine.buffer.pixels;
-	einfo->info.dest_buffer_row_bytes = ee->w * sizeof(int);
-	einfo->info.use_color_key = 0;
-	einfo->info.alpha_threshold = 0;
-	einfo->info.func.new_update_region = NULL;
-	einfo->info.func.free_update_region = NULL;
-	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
+        einfo->info.depth_type = EVAS_ENGINE_BUFFER_DEPTH_ARGB32;
+        einfo->info.dest_buffer = ee->engine.buffer.pixels;
+        einfo->info.dest_buffer_row_bytes = evas_object_image_stride_get(o);
+        einfo->info.use_color_key = 0;
+        einfo->info.alpha_threshold = 0;
+        einfo->info.func.new_update_region = NULL;
+        einfo->info.func.free_update_region = NULL;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
      }
    evas_key_modifier_add(ee->evas, "Shift");
    evas_key_modifier_add(ee->evas, "Control");
