@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -9,68 +5,45 @@
 #include <string.h>
 
 #include <Ecore.h>
+#include "ecore_private.h"
 #ifdef BUILD_ECORE_EVAS_DIRECTFB
 #include <Ecore_DirectFB.h>
 #endif
 
-#include "ecore_private.h"
 #include "ecore_evas_private.h"
 #include "Ecore_Evas.h"
 
 #ifdef BUILD_ECORE_EVAS_DIRECTFB
 static int _ecore_evas_init_count = 0;
-static int _ecore_evas_fps_debug = 0;
 static Ecore_Event_Handler *ecore_evas_event_handlers[13];
 
-static Ecore_Evas *ecore_evases = NULL;
 static Eina_Hash *ecore_evases_hash = NULL;
 
-static Ecore_Idle_Enterer *ecore_evas_directfb_idle_enterer = NULL;
-
-static void
+static int
 _ecore_evas_directfb_render(Ecore_Evas *ee)
 {
    Eina_List *updates, *ll;
    Ecore_Evas *ee2;
+   int rend = 0;
 
 #ifdef BUILD_ECORE_EVAS_SOFTWARE_BUFFER
    EINA_LIST_FOREACH(ee->sub_ecore_evas, ll, ee2)
      {
-	if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
-	_ecore_evas_buffer_render(ee2);
-	if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
+        if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
+        rend |= _ecore_evas_buffer_render(ee2);
+        if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
      }
 #endif
    if (ee->func.fn_pre_render) ee->func.fn_pre_render(ee);
    updates = evas_render_updates(ee->evas);
    if (updates)
      {
-	evas_render_updates_free(updates);
-	_ecore_evas_idle_timeout_update(ee);
+        evas_render_updates_free(updates);
+        _ecore_evas_idle_timeout_update(ee);
      }
    if (ee->func.fn_post_render) ee->func.fn_post_render(ee);
-}
 
-static int
-_ecore_evas_directfb_idle_enter(void *data __UNUSED__)
-{
-   Ecore_Evas *ee;
-   double t1 = 0.0;
-   double t2 = 0.0;
-
-   if (!ecore_evases) return 1;
-   if (_ecore_evas_fps_debug)
-     {
-	t1 = ecore_time_get();
-     }
-   EINA_INLIST_FOREACH(ecore_evases, ee)
-	_ecore_evas_directfb_render(ee);
-   if (_ecore_evas_fps_debug)
-     {
-	t2 = ecore_time_get();
-	_ecore_evas_fps_debug_rendertime_add(t2 - t1);
-     }
-   return 1;
+   return updates ? 1 : rend;
 }
 
 static char *
@@ -101,7 +74,7 @@ _ecore_evas_directfb_match(DFBWindowID win)
    return ee;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_key_down(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -110,13 +83,13 @@ _ecore_evas_directfb_event_key_down(void *data __UNUSED__, int type __UNUSED__,
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    evas_event_feed_key_down(ee->evas, e->name, e->name, e->string,
                             e->key_compose, e->time, NULL);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_key_up(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -125,13 +98,13 @@ _ecore_evas_directfb_event_key_up(void *data __UNUSED__, int type __UNUSED__, vo
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    evas_event_feed_key_up(ee->evas, e->name, e->name, e->string,
                           e->key_compose, e->time, NULL);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_motion(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -140,12 +113,12 @@ _ecore_evas_directfb_event_motion(void *data __UNUSED__, int type __UNUSED__, vo
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    _ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_button_down(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -154,13 +127,13 @@ _ecore_evas_directfb_event_button_down(void *data __UNUSED__, int type __UNUSED_
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    // _ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
    evas_event_feed_mouse_down(ee->evas, e->button, EVAS_BUTTON_NONE, e->time, NULL);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_button_up(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -170,13 +143,13 @@ _ecore_evas_directfb_event_button_up(void *data __UNUSED__, int type __UNUSED__,
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    //_ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
    evas_event_feed_mouse_up(ee->evas, e->button, flags, e->time, NULL);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_enter(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -185,13 +158,13 @@ _ecore_evas_directfb_event_enter(void *data __UNUSED__, int type __UNUSED__, voi
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    evas_event_feed_mouse_in(ee->evas, e->time, NULL);
    //_ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_leave(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -200,15 +173,15 @@ _ecore_evas_directfb_event_leave(void *data __UNUSED__, int type __UNUSED__, voi
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    evas_event_feed_mouse_out(ee->evas, e->time, NULL);
    //_ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
    if (ee->func.fn_mouse_out) ee->func.fn_mouse_out(ee);
    if (ee->prop.cursor.object) evas_object_hide(ee->prop.cursor.object);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_wheel(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -217,12 +190,12 @@ _ecore_evas_directfb_event_wheel(void *data __UNUSED__, int type __UNUSED__, voi
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    evas_event_feed_mouse_wheel(ee->evas, e->direction, e->z, e->time, NULL);
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_got_focus(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -231,12 +204,12 @@ _ecore_evas_directfb_event_got_focus(void *data __UNUSED__, int type __UNUSED__,
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    ee->prop.focused = 1;
-   return 1;
+   return EINA_TRUE;
 }
 
-static int
+static Eina_Bool
 _ecore_evas_directfb_event_lost_focus(void *data __UNUSED__, int type __UNUSED__, void *event)
 {
    Ecore_Evas *ee;
@@ -245,9 +218,9 @@ _ecore_evas_directfb_event_lost_focus(void *data __UNUSED__, int type __UNUSED__
    e = event;
    ee = _ecore_evas_directfb_match(e->win);
 
-   if (!ee) return 1; /* pass on event */
+   if (!ee) return EINA_TRUE; /* pass on event */
    ee->prop.focused = 0;
-   return 1;
+   return EINA_TRUE;
 }
 
 int
@@ -256,14 +229,10 @@ _ecore_evas_directfb_shutdown(void)
    _ecore_evas_init_count--;
    if (_ecore_evas_init_count == 0)
      {
-	int i;
+        int i;
 
-	while (ecore_evases) _ecore_evas_free(ecore_evases);
-	for (i = 0; i < 8; i++)
-	  ecore_event_handler_del(ecore_evas_event_handlers[i]);
-	ecore_idle_enterer_del(ecore_evas_directfb_idle_enterer);
-	ecore_evas_directfb_idle_enterer = NULL;
-	if (_ecore_evas_fps_debug) _ecore_evas_fps_debug_shutdown();
+        for (i = 0; i < 8; i++)
+          ecore_event_handler_del(ecore_evas_event_handlers[i]);
      }
    if (_ecore_evas_init_count < 0) _ecore_evas_init_count = 0;
    return _ecore_evas_init_count;
@@ -278,9 +247,6 @@ _ecore_evas_directfb_init(void)
 {
    _ecore_evas_init_count++;
    if (_ecore_evas_init_count > 1) return _ecore_evas_init_count;
-   if (getenv("ECORE_EVAS_FPS_DEBUG")) _ecore_evas_fps_debug = 1;
-   ecore_evas_directfb_idle_enterer = ecore_idle_enterer_add(_ecore_evas_directfb_idle_enter, NULL);
-   if (_ecore_evas_fps_debug) _ecore_evas_fps_debug_init();
 
    ecore_evas_event_handlers[0]  = ecore_event_handler_add(ECORE_DIRECTFB_EVENT_KEY_DOWN, _ecore_evas_directfb_event_key_down, NULL);
    ecore_evas_event_handlers[1]  = ecore_event_handler_add(ECORE_DIRECTFB_EVENT_KEY_UP, _ecore_evas_directfb_event_key_up, NULL);
@@ -307,7 +273,6 @@ _ecore_evas_directfb_free(Ecore_Evas *ee)
 {
    eina_hash_del(ecore_evases_hash, _ecore_evas_directfb_winid_str_get(ee->engine.directfb.window->id), ee);
    ecore_directfb_window_free(ee->engine.directfb.window);
-   ecore_evases = (Ecore_Evas *) eina_inlist_remove(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    _ecore_evas_directfb_shutdown();
    ecore_directfb_shutdown();
 }
@@ -327,13 +292,13 @@ _ecore_evas_directfb_resize(Ecore_Evas *ee, int w, int h)
    ee->h = h;
    if ((ee->rotation == 90) || (ee->rotation == 270))
      {
-	evas_output_size_set(ee->evas, ee->h, ee->w);
-	evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w);
+        evas_output_size_set(ee->evas, ee->h, ee->w);
+        evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w);
      }
    else
      {
-	evas_output_size_set(ee->evas, ee->w, ee->h);
-	evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
+        evas_output_size_set(ee->evas, ee->w, ee->h);
+        evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
      }
 }
 
@@ -387,14 +352,14 @@ _ecore_evas_directfb_object_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int lay
 
    if (ee->prop.cursor.object) evas_object_del(ee->prop.cursor.object);
 
-   if (obj == NULL)
+   if (!obj)
      {
-	ee->prop.cursor.object = NULL;
-	ee->prop.cursor.layer = 0;
-	ee->prop.cursor.hot.x = 0;
-	ee->prop.cursor.hot.y = 0;
-	ecore_directfb_window_cursor_show(ee->engine.directfb.window, 1);
-	return;
+        ee->prop.cursor.object = NULL;
+        ee->prop.cursor.layer = 0;
+        ee->prop.cursor.hot.x = 0;
+        ee->prop.cursor.hot.y = 0;
+        ecore_directfb_window_cursor_show(ee->engine.directfb.window, 1);
+        return;
 
      }
 
@@ -434,30 +399,33 @@ _ecore_evas_directfb_fullscreen_set(Ecore_Evas *ee, int on)
    ecore_directfb_window_size_get(ee->engine.directfb.window, &w, &h);
    if( (ee->w != w) || (ee->h != h))
      {
-	resized = 1;
-	ee->w = w;
-	ee->h = h;
-	if ((ee->rotation == 90) || (ee->rotation == 270))
-	  {
-	     evas_output_size_set(ee->evas, ee->h, ee->w);
-	     evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w);
-	  }
-	else
-	  {
-	     evas_output_size_set(ee->evas, ee->w, ee->h);
-	     evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
-	  }
+        resized = 1;
+        ee->w = w;
+        ee->h = h;
+        if ((ee->rotation == 90) || (ee->rotation == 270))
+          {
+             evas_output_size_set(ee->evas, ee->h, ee->w);
+             evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w);
+          }
+        else
+          {
+             evas_output_size_set(ee->evas, ee->w, ee->h);
+             evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
+          }
      }
    einfo = (Evas_Engine_Info_DirectFB *)evas_engine_info_get(ee->evas);
    if (einfo)
      {
-	einfo->info.surface = ee->engine.directfb.window->surface;
-	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
+        einfo->info.surface = ee->engine.directfb.window->surface;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
      }
    ee->prop.fullscreen = on;
    if (resized)
      {
-	if(ee->func.fn_resize) ee->func.fn_resize(ee);
+        if(ee->func.fn_resize) ee->func.fn_resize(ee);
      }
 }
 
@@ -469,53 +437,56 @@ _ecore_evas_directfb_window_get(const Ecore_Evas *ee)
 #endif
 
 #ifdef BUILD_ECORE_EVAS_DIRECTFB
-static const Ecore_Evas_Engine_Func _ecore_directfb_engine_func =
+static Ecore_Evas_Engine_Func _ecore_directfb_engine_func =
 {
-   _ecore_evas_directfb_free,	/* free an ecore_evas */
-     NULL,				/* cb resize */
-     NULL,				/* cb move */
-     NULL,				/* cb show */
-     NULL,				/* cb hide */
-     NULL,				/* cb delete request */
-     NULL,				/* cb destroy */
-     NULL,				/* cb focus in */
-     NULL,				/* cb focus out */
+   _ecore_evas_directfb_free,        /* free an ecore_evas */
+     NULL,                                /* cb resize */
+     NULL,                                /* cb move */
+     NULL,                                /* cb show */
+     NULL,                                /* cb hide */
+     NULL,                                /* cb delete request */
+     NULL,                                /* cb destroy */
+     NULL,                                /* cb focus in */
+     NULL,                                /* cb focus out */
      NULL,                              /* cb sticky */
      NULL,                              /* cb unsticky */
-     NULL,				/* cb mouse in */
-     NULL,				/* cb mouse out */
-     NULL,				/* cb pre render */
-     NULL,				/* cb post render */
-     _ecore_evas_directfb_move,	        /* move */
+     NULL,                                /* cb mouse in */
+     NULL,                                /* cb mouse out */
+     NULL,                                /* cb pre render */
+     NULL,                                /* cb post render */
+     _ecore_evas_directfb_move,                /* move */
      NULL,                              /* managed move */
-     _ecore_evas_directfb_resize,	/* resize */
-     NULL,				/* move resize */
+     _ecore_evas_directfb_resize,        /* resize */
+     NULL,                                /* move resize */
      NULL,//_ecore_evas_directfb_rotation_set,/* rotation */
      _ecore_evas_directfb_shaped_set,   /* shaped */
-     _ecore_evas_directfb_show,	        /* show */
-     _ecore_evas_directfb_hide,	        /* hide */
-     NULL,				/* raise */
-     NULL,				/* lower */
-     NULL,				/* activate */
-     NULL,				/* title set */
-     NULL,				/* name class set */
-     NULL,				/* size min */
-     NULL,				/* size max */
-     NULL,				/* size base */
-     NULL,				/* size step */
+     _ecore_evas_directfb_show,                /* show */
+     _ecore_evas_directfb_hide,                /* hide */
+     NULL,                                /* raise */
+     NULL,                                /* lower */
+     NULL,                                /* activate */
+     NULL,                                /* title set */
+     NULL,                                /* name class set */
+     NULL,                                /* size min */
+     NULL,                                /* size max */
+     NULL,                                /* size base */
+     NULL,                                /* size step */
      _ecore_evas_directfb_object_cursor_set, /* set cursor to an evas object */
-     NULL,				/* layer set */
-     _ecore_evas_directfb_focus_set,	/* focus */
-     NULL,				/* iconified */
-     NULL,				/* borderless */
-     NULL,				/* override */
-     NULL,				/* maximized */
+     NULL,                                /* layer set */
+     _ecore_evas_directfb_focus_set,        /* focus */
+     NULL,                                /* iconified */
+     NULL,                                /* borderless */
+     NULL,                                /* override */
+     NULL,                                /* maximized */
      _ecore_evas_directfb_fullscreen_set,/* fullscreen */
-     NULL,				/* avoid damage */
-     NULL,				/* withdrawn */
-     NULL,				/* sticky */
+     NULL,                                /* avoid damage */
+     NULL,                                /* withdrawn */
+     NULL,                                /* sticky */
      NULL,                              /* ignore events */
-     NULL                               /* alpha */
+     NULL,                              /* alpha */
+     NULL, //transparent
+     
+     NULL // render
 };
 #endif
 
@@ -568,11 +539,17 @@ ecore_evas_directfb_new(const char *disp_name, int windowed, int x, int y, int w
    ee->engine.directfb.window = window;
    if (einfo)
      {
-	einfo->info.dfb = ecore_directfb_interface_get();
-	einfo->info.surface = window->surface;
-	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
+        einfo->info.dfb = ecore_directfb_interface_get();
+        einfo->info.surface = window->surface;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
      }
-   ecore_evases = (Ecore_Evas *) eina_inlist_prepend(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
+   
+   ee->engine.func->fn_render = _ecore_evas_directfb_render;
+   _ecore_evas_register(ee);
+   
    if (!ecore_evases_hash)
      ecore_evases_hash = eina_hash_string_superfast_new(NULL);
    eina_hash_add(ecore_evases_hash, _ecore_evas_directfb_winid_str_get(ee->engine.directfb.window->id), ee);
