@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -56,9 +52,9 @@ _ecore_evas_wince_render(Ecore_Evas *ee)
 
    EINA_LIST_FOREACH(ee->sub_ecore_evas, ll, ee2)
      {
-	if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
-	rend |= _ecore_evas_buffer_render(ee2);
-	if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
+        if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
+        rend |= _ecore_evas_buffer_render(ee2);
+        if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
      }
 #endif
    if (ee->func.fn_pre_render) ee->func.fn_pre_render(ee);
@@ -114,10 +110,10 @@ _ecore_evas_wince_shutdown(void)
    _ecore_evas_init_count--;
    if (_ecore_evas_init_count == 0)
      {
-	int i;
+        int i;
 
-	for (i = 0; i < ECORE_EVAS_EVENT_COUNT; i++)
-	  ecore_event_handler_del(ecore_evas_event_handlers[i]);
+        for (i = 0; i < ECORE_EVAS_EVENT_COUNT; i++)
+          ecore_event_handler_del(ecore_evas_event_handlers[i]);
         ecore_event_evas_shutdown();
      }
 
@@ -404,65 +400,65 @@ _ecore_evas_wince_move_resize(Ecore_Evas *ee, int x, int y, int width, int heigh
 /*    if (rot_dif < 0) rot_dif = -rot_dif; */
 /*    if (!strcmp(ee->driver, "software_ddraw")) */
 /*      { */
-/*	Evas_Engine_Info_Software_16_WinCE *einfo; */
+/*        Evas_Engine_Info_Software_16_WinCE *einfo; */
 
-/*	einfo = (Evas_Engine_Info_Software_16_WinCE *)evas_engine_info_get(ee->evas); */
-/*	if (!einfo) return; */
-/*	if (rot_dif != 180) */
-/*	  { */
-/*	     int minw, minh, maxw, maxh, basew, baseh, stepw, steph; */
+/*        einfo = (Evas_Engine_Info_Software_16_WinCE *)evas_engine_info_get(ee->evas); */
+/*        if (!einfo) return; */
+/*        if (rot_dif != 180) */
+/*          { */
+/*             int minw, minh, maxw, maxh, basew, baseh, stepw, steph; */
 
-/*	     einfo->info.rotation = rotation; */
-/*	     evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo); */
-/*	     if (!ee->prop.fullscreen) */
-/*	       { */
-/*		  ecore_wince_window_resize(ee->prop.window, ee->h, ee->w); */
-/*		  ee->expecting_resize.w = ee->h; */
-/*		  ee->expecting_resize.h = ee->w; */
-/*	       } */
-/*	     else */
-/*	       { */
-/*		  int w, h; */
+/*             einfo->info.rotation = rotation; */
+/*             evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo); */
+/*             if (!ee->prop.fullscreen) */
+/*               { */
+/*                  ecore_wince_window_resize(ee->prop.window, ee->h, ee->w); */
+/*                  ee->expecting_resize.w = ee->h; */
+/*                  ee->expecting_resize.h = ee->w; */
+/*               } */
+/*             else */
+/*               { */
+/*                  int w, h; */
 
-/*		  ecore_wince_window_size_get(ee->prop.window, &w, &h); */
-/*		  ecore_wince_window_resize(ee->prop.window, h, w); */
-/*		  if ((rotation == 0) || (rotation == 180)) */
-/*		    { */
-/*		       evas_output_size_set(ee->evas, ee->w, ee->h); */
-/*		       evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h); */
-/*		    } */
-/*		  else */
-/*		    { */
-/*		       evas_output_size_set(ee->evas, ee->h, ee->w); */
-/*		       evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w); */
-/*		    } */
-/*		  if (ee->func.fn_resize) ee->func.fn_resize(ee); */
-/*	       } */
-/*	     ecore_evas_size_min_get(ee, &minw, &minh); */
-/*	     ecore_evas_size_max_get(ee, &maxw, &maxh); */
-/*	     ecore_evas_size_base_get(ee, &basew, &baseh); */
-/*	     ecore_evas_size_step_get(ee, &stepw, &steph); */
-/*	     ee->rotation = rotation; */
-/*	     ecore_evas_size_min_set(ee, minh, minw); */
-/*	     ecore_evas_size_max_set(ee, maxh, maxw); */
-/*	     ecore_evas_size_base_set(ee, baseh, basew); */
-/*	     ecore_evas_size_step_set(ee, steph, stepw); */
-/*	     _ecore_evas_wince_mouse_move_process(ee, ee->mouse.x, ee->mouse.y, */
+/*                  ecore_wince_window_size_get(ee->prop.window, &w, &h); */
+/*                  ecore_wince_window_resize(ee->prop.window, h, w); */
+/*                  if ((rotation == 0) || (rotation == 180)) */
+/*                    { */
+/*                       evas_output_size_set(ee->evas, ee->w, ee->h); */
+/*                       evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h); */
+/*                    } */
+/*                  else */
+/*                    { */
+/*                       evas_output_size_set(ee->evas, ee->h, ee->w); */
+/*                       evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w); */
+/*                    } */
+/*                  if (ee->func.fn_resize) ee->func.fn_resize(ee); */
+/*               } */
+/*             ecore_evas_size_min_get(ee, &minw, &minh); */
+/*             ecore_evas_size_max_get(ee, &maxw, &maxh); */
+/*             ecore_evas_size_base_get(ee, &basew, &baseh); */
+/*             ecore_evas_size_step_get(ee, &stepw, &steph); */
+/*             ee->rotation = rotation; */
+/*             ecore_evas_size_min_set(ee, minh, minw); */
+/*             ecore_evas_size_max_set(ee, maxh, maxw); */
+/*             ecore_evas_size_base_set(ee, baseh, basew); */
+/*             ecore_evas_size_step_set(ee, steph, stepw); */
+/*             _ecore_evas_wince_mouse_move_process(ee, ee->mouse.x, ee->mouse.y, */
 /*                                                   ecore_wince_current_time_get()); */
-/*	  } */
-/*	else */
-/*	  { */
-/*	     einfo->info.rotation = rotation; */
-/*	     evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo); */
-/*	     ee->rotation = rotation; */
-/*	     _ecore_evas_wince_mouse_move_process(ee, ee->mouse.x, ee->mouse.y, */
+/*          } */
+/*        else */
+/*          { */
+/*             einfo->info.rotation = rotation; */
+/*             evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo); */
+/*             ee->rotation = rotation; */
+/*             _ecore_evas_wince_mouse_move_process(ee, ee->mouse.x, ee->mouse.y, */
 /*                                                   ecore_wince_current_time_get()); */
-/*	     if (ee->func.fn_resize) ee->func.fn_resize(ee); */
-/*	  } */
-/*	if ((ee->rotation == 90) || (ee->rotation == 270)) */
-/*	  evas_damage_rectangle_add(ee->evas, 0, 0, ee->h, ee->w); */
-/*	else */
-/*	  evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h); */
+/*             if (ee->func.fn_resize) ee->func.fn_resize(ee); */
+/*          } */
+/*        if ((ee->rotation == 90) || (ee->rotation == 270)) */
+/*          evas_damage_rectangle_add(ee->evas, 0, 0, ee->h, ee->w); */
+/*        else */
+/*          evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h); */
 /*      } */
 /* } */
 
@@ -571,12 +567,12 @@ _ecore_evas_wince_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int layer, int ho
 
    if (obj == NULL)
      {
-	ee->prop.cursor.object = NULL;
-	ee->prop.cursor.layer = 0;
-	ee->prop.cursor.hot.x = 0;
-	ee->prop.cursor.hot.y = 0;
-	ecore_wince_window_cursor_show(ee->prop.window, 1);
-	return;
+        ee->prop.cursor.object = NULL;
+        ee->prop.cursor.layer = 0;
+        ee->prop.cursor.hot.x = 0;
+        ee->prop.cursor.hot.y = 0;
+        ecore_wince_window_cursor_show(ee->prop.window, 1);
+        return;
      }
 
    ee->prop.cursor.object = obj;
@@ -589,8 +585,8 @@ _ecore_evas_wince_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int layer, int ho
    evas_pointer_output_xy_get(ee->evas, &x, &y);
    evas_object_layer_set(ee->prop.cursor.object, ee->prop.cursor.layer);
    evas_object_move(ee->prop.cursor.object,
-		    x - ee->prop.cursor.hot.x,
-		    y - ee->prop.cursor.hot.y);
+                    x - ee->prop.cursor.hot.x,
+                    y - ee->prop.cursor.hot.y);
    evas_object_pass_events_set(ee->prop.cursor.object, 1);
    if (evas_pointer_inside_get(ee->evas))
      evas_object_show(ee->prop.cursor.object);
@@ -665,11 +661,14 @@ _ecore_evas_wince_fullscreen_set(Ecore_Evas *ee, int on)
    }
 
    einfo = (Evas_Engine_Info_Software_16_WinCE *)evas_engine_info_get(ecore_evas_get(ee));
-   if (einfo != NULL)
+   if (einfo)
      {
         einfo->info.fullscreen = !!on;
 /*         einfo->info.layered = window->shape.layered; */
-        evas_engine_info_set(ecore_evas_get(ee), (Evas_Engine_Info *)einfo);
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
      }
 }
 
@@ -809,16 +808,23 @@ ecore_evas_software_wince_new_internal(int                 backend,
         einfo->info.backend = backend;
         einfo->info.rotation = 0;
         einfo->info.fullscreen = fullscreen;
-	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
 
         ecore_wince_window_backend_set((Ecore_WinCE_Window *)ee->prop.window, backend);
-        ecore_wince_window_suspend_set((Ecore_WinCE_Window *)ee->prop.window, einfo->func.suspend);
-        ecore_wince_window_resume_set((Ecore_WinCE_Window *)ee->prop.window, einfo->func.resume);
+        ecore_wince_window_suspend_cb_set((Ecore_WinCE_Window *)ee->prop.window, einfo->func.suspend);
+        ecore_wince_window_resume_cb_set((Ecore_WinCE_Window *)ee->prop.window, einfo->func.resume);
      }
 
    ee->engine.func->fn_render = _ecore_evas_wince_render;
    _ecore_evas_register(ee);
-   ecore_event_window_register(ee->prop.window, ee, ee->evas, (Ecore_Event_Mouse_Move_Cb)_ecore_evas_mouse_move_process);
+   ecore_event_window_register(ee->prop.window, ee, ee->evas,
+                               (Ecore_Event_Mouse_Move_Cb)_ecore_evas_mouse_move_process,
+                               (Ecore_Event_Multi_Move_Cb)_ecore_evas_mouse_multi_move_process,
+                               (Ecore_Event_Multi_Down_Cb)_ecore_evas_mouse_multi_down_process,
+                               (Ecore_Event_Multi_Up_Cb)_ecore_evas_mouse_multi_up_process);
    evas_focus_in(ee->evas);
 
    return ee;
