@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -22,31 +18,34 @@ static int _ecore_fb_init_count = 0;
 static int _ecore_fb_console_w = 0;
 static int _ecore_fb_console_h = 0;
 
-static double _ecore_fb_double_click_time = 0.25;
-
-
 /**
- * @defgroup Ecore_FB_Library_Group Framebuffer Library Functions
+ * @addtogroup Ecore_FB_Group Ecore_FB - Frame buffer convenience functions.
  *
- * Functions used to set up and shut down the Ecore_Framebuffer functions.
+ * @{
  */
 
 /**
- * Sets up the Ecore_Fb library.
- * @param   name device target name
- * @return  @c 0 on failure.  Otherwise, the number of times the library has
- *          been initialised without being shut down.
- * @ingroup Ecore_FB_Library_Group
+ * @brief Initialize the Ecore_Fb library.
+ *
+ * @param name Device target name.
+ * @return 1 or greater on success, 0 on error.
+ *
+ * This function sets up all the Ecore_Fb library. It returns 0 on
+ * failure, otherwise it returns the number of times it has already
+ * been called.
+ *
+ * When Ecore_Fb is not used anymore, call ecore_fb_shutdown() to shut down
+ * the Ecore_Fb library.
  */
 EAPI int
 ecore_fb_init(const char *name __UNUSED__)
 {
    if (++_ecore_fb_init_count != 1)
-     return _ecore_fb_init_count;
-
+      return _ecore_fb_init_count;
+   
    if (!ecore_fb_vt_init())
-     return --_ecore_fb_init_count;
-
+      return --_ecore_fb_init_count;
+   
    ECORE_FB_EVENT_KEY_DOWN          = ecore_event_type_new();
    ECORE_FB_EVENT_KEY_UP            = ecore_event_type_new();
    ECORE_FB_EVENT_MOUSE_BUTTON_DOWN = ecore_event_type_new();
@@ -59,16 +58,19 @@ ecore_fb_init(const char *name __UNUSED__)
 }
 
 /**
- * Shuts down the Ecore_Fb library. 
- * @return  @c The number of times the system has been initialised without
- *             being shut down.
- * @ingroup Ecore_FB_Library_Group
+ * @brief Shut down the Ecore_Fb library.
+ *
+ * @return 0 when the library is completely shut down, 1 or
+ * greater otherwise.
+ *
+ * This function shuts down the Ecore_Fb library. It returns 0 when it has
+ * been called the same number of times than ecore_fb_init().
  */
 EAPI int
 ecore_fb_shutdown(void)
 {    
    if (--_ecore_fb_init_count != 0)
-     return _ecore_fb_init_count;
+      return _ecore_fb_init_count;
 
    ecore_fb_vt_shutdown();
 
@@ -77,9 +79,16 @@ ecore_fb_shutdown(void)
 
 
 /**
- * Retrieves the width and height of the current frame buffer in pixels.
+ * @brief Retrieve the width and height of the current frame buffer in
+ * pixels.
+ *
  * @param w Pointer to an integer in which to store the width.
  * @param h Pointer to an interge in which to store the height.
+ *
+ * This function retrieves the size of the current frame buffer in
+ * pixels. @p w and @p h can be buffers that will be filled with the
+ * corresponding values. If one of them is @c NULL, nothing will be
+ * done for that parameter.
  */
 EAPI void
 ecore_fb_size_get(int *w, int *h)
@@ -97,17 +106,22 @@ _ecore_fb_size_get(int *w, int *h)
    fb = open("/dev/fb0", O_RDWR);
    if (fb < 0)
      {
-	if (w) *w = 0;
-	if (h) *h = 0;
-	return;
+        if (w) *w = 0;
+        if (h) *h = 0;
+        return;
      }
    if (ioctl(fb, FBIOGET_VSCREENINFO, &fb_var) == -1)
      {
-	if (w) *w = 0;
-	if (h) *h = 0;
-	return;
+        if (w) *w = 0;
+        if (h) *h = 0;
+        close(fb);
+        return;
      }
    close(fb);
    if (w) *w = fb_var.xres;
    if (h) *h = fb_var.yres;
 }
+
+/**
+ * @}
+ */
