@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -40,8 +36,9 @@ ecore_imf_init(void)
    if (++_ecore_imf_init_count != 1) return _ecore_imf_init_count;
    
    if (!ecore_init()) return --_ecore_imf_init_count;
-   _ecore_imf_log_dom = eina_log_domain_register("EcoreIMF", ECORE_IMF_DEFAULT_LOG_COLOR);
-   if (_ecore_imf_log_dom < 0) 
+   _ecore_imf_log_dom = eina_log_domain_register
+     ("ecore_imf", ECORE_IMF_DEFAULT_LOG_COLOR);
+   if (_ecore_imf_log_dom < 0)
      {
         EINA_LOG_ERR("Impossible to create a log domain for the Ecore IMF module.");
         ecore_shutdown();
