@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -28,7 +24,7 @@
  * Note that the caller is responsible for freeing the Eina_List
  * when finished with it. There is no need to finish the list strings.
  *
- * @return Return an EIna_List of strings;
+ * @return Return an Eina_List of strings;
  *         on failure it returns NULL.
  * @ingroup Ecore_IMF_Context_Group
  */
@@ -95,8 +91,8 @@ ecore_imf_context_default_id_by_canvas_type_get(const char *canvas_type)
    id = getenv("ECORE_IMF_MODULE");
    if (id)
      {
-	if (strcmp(id, "none") == 0) return NULL;
-	if (ecore_imf_module_get(id)) return id;
+        if (strcmp(id, "none") == 0) return NULL;
+        if (ecore_imf_module_get(id)) return id;
      }
 
    modules = ecore_imf_module_available_get();
@@ -116,24 +112,24 @@ ecore_imf_context_default_id_by_canvas_type_get(const char *canvas_type)
 
    EINA_LIST_FREE(modules, module)
      {
-	if (canvas_type &&
-	    strcmp(module->info->canvas_type, canvas_type) == 0)
-	  continue;
+        if (canvas_type &&
+            strcmp(module->info->canvas_type, canvas_type) == 0)
+          continue;
 
-	const char *p = module->info->default_locales;
-	while (p)
-	  {
-	     const char *q = strchr(p, ':');
-	     int goodness = _ecore_imf_context_match_locale(locale, p, q ? (size_t)(q - p) : strlen (p));
+        const char *p = module->info->default_locales;
+        while (p)
+          {
+             const char *q = strchr(p, ':');
+             int goodness = _ecore_imf_context_match_locale(locale, p, q ? (size_t)(q - p) : strlen (p));
 
-	      if (goodness > best_goodness)
-		{
-		   id = module->info->id;
-		   best_goodness = goodness;
-		}
+              if (goodness > best_goodness)
+                {
+                   id = module->info->id;
+                   best_goodness = goodness;
+                }
 
-	      p = q ? q + 1 : NULL;
-	  }
+              p = q ? q + 1 : NULL;
+          }
      }
 
    free(locale);
@@ -176,9 +172,9 @@ ecore_imf_context_add(const char *id)
    ctx = ecore_imf_module_context_create(id);
    if (!ctx || !ctx->klass) return NULL;
    if (ctx->klass->add) ctx->klass->add(ctx);
-   /* default use_preedit is 1, so let's make sure it's
+   /* default use_preedit is EINA_TRUE, so let's make sure it's
     * set on the immodule */
-   ecore_imf_context_use_preedit_set(ctx, 1);
+   ecore_imf_context_use_preedit_set(ctx, EINA_TRUE);
    /* default input_mode is ECORE_IMF_INPUT_MODE_FULL, so let's make sure it's
     * set on the immodule */
    ecore_imf_context_input_mode_set(ctx, ECORE_IMF_INPUT_MODE_FULL);
@@ -198,9 +194,9 @@ ecore_imf_context_info_get(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_info_get");
-	return NULL;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_info_get");
+        return NULL;
      }
    return ctx->module->info;
 }
@@ -216,9 +212,9 @@ ecore_imf_context_del(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_del");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_del");
+        return;
      }
    if (ctx->klass->del) ctx->klass->del(ctx);
    ECORE_MAGIC_SET(ctx, ECORE_MAGIC_NONE);
@@ -241,9 +237,9 @@ ecore_imf_context_client_window_set(Ecore_IMF_Context *ctx, void *window)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_client_window_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_client_window_set");
+        return;
      }
    if (ctx->klass->client_window_set) ctx->klass->client_window_set(ctx, window);
 }
@@ -257,8 +253,8 @@ ecore_imf_context_client_window_set(Ecore_IMF_Context *ctx, void *window)
  * also be used for purposes internal to the Input Method Context.
  *
  * @param ctx An #Ecore_IMF_Context.
- * @param canas The client canvas. This may be NULL to indicate
- *              that the previous client canvas no longer exists.
+ * @param canvas The client canvas. This may be NULL to indicate
+ *               that the previous client canvas no longer exists.
  * @ingroup Ecore_IMF_Context_Group
  */
 EAPI void
@@ -266,9 +262,9 @@ ecore_imf_context_client_canvas_set(Ecore_IMF_Context *ctx, void *canvas)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_client_window_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_client_canvas_set");
+        return;
      }
    if (ctx->klass->client_canvas_set) ctx->klass->client_canvas_set(ctx, canvas);
 }
@@ -284,9 +280,9 @@ ecore_imf_context_show(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_show");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_show");
+        return;
      }
    if (ctx->klass->show) ctx->klass->show(ctx);
 }
@@ -302,14 +298,14 @@ ecore_imf_context_hide(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_hide");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_hide");
+        return;
      }
    if (ctx->klass->hide) ctx->klass->hide(ctx);
 }
 
-/*
+/**
  * Retrieve the current preedit string and cursor position
  * for the Input Method Context.
  *
@@ -325,16 +321,16 @@ ecore_imf_context_preedit_string_get(Ecore_IMF_Context *ctx, char **str, int *cu
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_preedit_string_get");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_preedit_string_get");
+        return;
      }
    if (ctx->klass->preedit_string_get)
      ctx->klass->preedit_string_get(ctx, str, cursor_pos);
    else
      {
-	if (str) *str = strdup("");
-	if (cursor_pos) *cursor_pos = 0;
+        if (str) *str = strdup("");
+        if (cursor_pos) *cursor_pos = 0;
      }
 }
 
@@ -350,9 +346,9 @@ ecore_imf_context_focus_in(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_focus_in");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_focus_in");
+        return;
      }
    if (ctx->klass->focus_in) ctx->klass->focus_in(ctx);
 }
@@ -369,9 +365,9 @@ ecore_imf_context_focus_out(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_focus_out");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_focus_out");
+        return;
      }
    if (ctx->klass->focus_out) ctx->klass->focus_out(ctx);
 }
@@ -389,9 +385,9 @@ ecore_imf_context_reset(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_reset");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_reset");
+        return;
      }
    if (ctx->klass->reset) ctx->klass->reset(ctx);
 }
@@ -409,17 +405,17 @@ ecore_imf_context_cursor_position_set(Ecore_IMF_Context *ctx, int cursor_pos)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_cursor_position_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_cursor_position_set");
+        return;
      }
    if (ctx->klass->cursor_position_set) ctx->klass->cursor_position_set(ctx, cursor_pos);
 }
 
 /**
  * Set whether the IM context should use the preedit string
- * to display feedback. If @use_preedit is 0 (default
- * is 1), then the IM context may use some other method to display
+ * to display feedback. If @use_preedit is EINA_FALSE (default
+ * is EINA_TRUE), then the IM context may use some other method to display
  * feedback, such as displaying it in a child of the root window.
  *
  * @param ctx An #Ecore_IMF_Context.
@@ -427,13 +423,13 @@ ecore_imf_context_cursor_position_set(Ecore_IMF_Context *ctx, int cursor_pos)
  * @ingroup Ecore_IMF_Context_Group
  */
 EAPI void
-ecore_imf_context_use_preedit_set(Ecore_IMF_Context *ctx, int use_preedit)
+ecore_imf_context_use_preedit_set(Ecore_IMF_Context *ctx, Eina_Bool use_preedit)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_use_preedit_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_use_preedit_set");
+        return;
      }
    if (ctx->klass->use_preedit_set) ctx->klass->use_preedit_set(ctx, use_preedit);
 }
@@ -450,13 +446,13 @@ ecore_imf_context_use_preedit_set(Ecore_IMF_Context *ctx, int use_preedit)
  * @ingroup Ecore_IMF_Context_Group
  */
 EAPI void
-ecore_imf_context_retrieve_surrounding_callback_set(Ecore_IMF_Context *ctx, int (*func)(void *data, Ecore_IMF_Context *ctx, char **text, int *cursor_pos), const void *data)
+ecore_imf_context_retrieve_surrounding_callback_set(Ecore_IMF_Context *ctx, Eina_Bool (*func)(void *data, Ecore_IMF_Context *ctx, char **text, int *cursor_pos), const void *data)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_retrieve_surrounding_callback_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_retrieve_surrounding_callback_set");
+        return;
      }
 
    ctx->retrieve_surrounding_func = func;
@@ -479,9 +475,9 @@ ecore_imf_context_input_mode_set(Ecore_IMF_Context *ctx, Ecore_IMF_Input_Mode in
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_input_mode_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_input_mode_set");
+        return;
      }
    if (ctx->klass->input_mode_set) ctx->klass->input_mode_set(ctx, input_mode);
    ctx->input_mode = input_mode;
@@ -501,39 +497,39 @@ ecore_imf_context_input_mode_get(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_input_mode_set");
-	return 0;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_input_mode_set");
+        return 0;
      }
    return ctx->input_mode;
 }
 
 /**
  * Allow an Ecore Input Context to internally handle an event.
- * If this function returns 1, then no further processing
+ * If this function returns EINA_TRUE, then no further processing
  * should be done for this event.
  *
  * Input methods must be able to accept all types of events (simply
- * returning 0 if the event was not handled), but there is no
+ * returning EINA_FALSE if the event was not handled), but there is no
  * obligation of any events to be submitted to this function.
  *
  * @param ctx An #Ecore_IMF_Context.
  * @param type The type of event defined by #Ecore_IMF_Event_Type.
  * @param event The event itself.
- * @return 1 if the event was handled; otherwise 0.
+ * @return EINA_TRUE if the event was handled; otherwise EINA_FALSE.
  * @ingroup Ecore_IMF_Context_Group
  */
-EAPI int
+EAPI Eina_Bool
 ecore_imf_context_filter_event(Ecore_IMF_Context *ctx, Ecore_IMF_Event_Type type, Ecore_IMF_Event *event)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_filter_event");
-	return 0;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_filter_event");
+        return EINA_FALSE;
      }
    if (ctx->klass->filter_event) return ctx->klass->filter_event(ctx, type, event);
-   return 0;
+   return EINA_FALSE;
 }
 
 /**
@@ -558,7 +554,7 @@ ecore_imf_context_new(const Ecore_IMF_Context_Class *ctxc)
    Ecore_IMF_Context *ctx;
 
    if (!ctxc) return NULL;
-   ctx = malloc(sizeof(Ecore_IMF_Context));
+   ctx = calloc(1, sizeof(Ecore_IMF_Context));
    if (!ctx) return NULL;
    ECORE_MAGIC_SET(ctx, ECORE_MAGIC_CONTEXT);
    ctx->klass = ctxc;
@@ -585,9 +581,9 @@ ecore_imf_context_data_set(Ecore_IMF_Context *ctx, void *data)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_data_set");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_data_set");
+        return;
      }
    ctx->data = data;
 }
@@ -605,9 +601,9 @@ EAPI void *ecore_imf_context_data_get(Ecore_IMF_Context *ctx)
 {
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_data_get");
-	return NULL;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_data_get");
+        return NULL;
      }
    return ctx->data;
 }
@@ -626,33 +622,33 @@ EAPI void *ecore_imf_context_data_get(Ecore_IMF_Context *ctx)
  * @param ctx An #Ecore_IMF_Context.
  * @param text Location to store a UTF-8 encoded string of text
  *             holding context around the insertion point.
- *             If the function returns 1, then you must free
+ *             If the function returns EINA_TRUE, then you must free
  *             the result stored in this location with free().
  * @param cursor_pos Location to store the position in characters of
  *                   the insertion cursor within @text.
- * @return 1 if surrounding text was provided; otherwise 0.
+ * @return EINA_TRUE if surrounding text was provided; otherwise EINA_FALSE.
  * @ingroup Ecore_IMF_Context_Module_Group
  */
-EAPI int
+EAPI Eina_Bool
 ecore_imf_context_surrounding_get(Ecore_IMF_Context *ctx, char **text, int *cursor_pos)
 {
-   int result = 0;
+   int result = EINA_FALSE;
 
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_surrounding_get");
-	return 0;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_surrounding_get");
+        return EINA_FALSE;
      }
 
    if (ctx->retrieve_surrounding_func)
      {
-	result = ctx->retrieve_surrounding_func(ctx->retrieve_surrounding_data, ctx, text, cursor_pos);
-	if (!result)
-	  {
-	     if (text) *text = NULL;
-	     if (cursor_pos) *cursor_pos = 0;
-	  }
+        result = ctx->retrieve_surrounding_func(ctx->retrieve_surrounding_data, ctx, text, cursor_pos);
+        if (!result)
+          {
+             if (text) *text = NULL;
+             if (cursor_pos) *cursor_pos = 0;
+          }
      }
    return result;
 }
@@ -676,15 +672,15 @@ ecore_imf_context_preedit_start_event_add(Ecore_IMF_Context *ctx)
 
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_preedit_start_event_add");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_preedit_start_event_add");
+        return;
      }
 
    ev = malloc(sizeof(Ecore_IMF_Event_Preedit_Start));
    ev->ctx = ctx;
    ecore_event_add(ECORE_IMF_EVENT_PREEDIT_START,
-		   ev, _ecore_imf_event_free_preedit, NULL);
+                   ev, _ecore_imf_event_free_preedit, NULL);
 }
 
 /**
@@ -700,15 +696,15 @@ ecore_imf_context_preedit_end_event_add(Ecore_IMF_Context *ctx)
 
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_preedit_end_event_add");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_preedit_end_event_add");
+        return;
      }
 
    ev = malloc(sizeof(Ecore_IMF_Event_Preedit_End));
    ev->ctx = ctx;
    ecore_event_add(ECORE_IMF_EVENT_PREEDIT_END,
-		   ev, _ecore_imf_event_free_preedit, NULL);
+                   ev, _ecore_imf_event_free_preedit, NULL);
 }
 
 /**
@@ -724,15 +720,15 @@ ecore_imf_context_preedit_changed_event_add(Ecore_IMF_Context *ctx)
 
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_preedit_changed_event_add");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_preedit_changed_event_add");
+        return;
      }
 
    ev = malloc(sizeof(Ecore_IMF_Event_Preedit_Changed));
    ev->ctx = ctx;
    ecore_event_add(ECORE_IMF_EVENT_PREEDIT_CHANGED,
-		   ev, _ecore_imf_event_free_preedit, NULL);
+                   ev, _ecore_imf_event_free_preedit, NULL);
 }
 
 static void
@@ -759,16 +755,16 @@ ecore_imf_context_commit_event_add(Ecore_IMF_Context *ctx, const char *str)
 
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_commit_event_add");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_commit_event_add");
+        return;
      }
 
    ev = malloc(sizeof(Ecore_IMF_Event_Commit));
    ev->ctx = ctx;
    ev->str = str ? strdup(str) : NULL;
    ecore_event_add(ECORE_IMF_EVENT_COMMIT,
-		   ev, _ecore_imf_event_free_commit, NULL);
+                   ev, _ecore_imf_event_free_commit, NULL);
 
 }
 
@@ -793,9 +789,9 @@ ecore_imf_context_delete_surrounding_event_add(Ecore_IMF_Context *ctx, int offse
 
    if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
      {
-	ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
-			 "ecore_imf_context_delete_surrounding_event_add");
-	return;
+        ECORE_MAGIC_FAIL(ctx, ECORE_MAGIC_CONTEXT,
+                         "ecore_imf_context_delete_surrounding_event_add");
+        return;
      }
 
    ev = malloc(sizeof(Ecore_IMF_Event_Delete_Surrounding));
@@ -803,5 +799,5 @@ ecore_imf_context_delete_surrounding_event_add(Ecore_IMF_Context *ctx, int offse
    ev->offset = offset;
    ev->n_chars = n_chars;
    ecore_event_add(ECORE_IMF_EVENT_DELETE_SURROUNDING,
-		   ev, _ecore_imf_event_free_delete_surrounding, NULL);
+                   ev, _ecore_imf_event_free_delete_surrounding, NULL);
 }
