@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifndef __ECORE_WIN32_PRIVATE_H__
 #define __ECORE_WIN32_PRIVATE_H__
 
@@ -103,6 +99,16 @@ struct _Ecore_Win32_Window
       unsigned int   layered : 1;
    } shape;
 
+   struct {
+     unsigned int x;
+     unsigned int y;
+     unsigned int w;
+     unsigned int h;
+     unsigned int px;
+     unsigned int py;
+     unsigned int dragging : 1;
+   } drag;
+
    void *dnd_drop_target;
 };
 
