@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -19,8 +15,13 @@
 #include "Ecore_WinCE.h"
 #include "ecore_wince_private.h"
 
+/*============================================================================*
+ *                                  Local                                     *
+ *============================================================================*/
 
-/***** Private declarations *****/
+/**
+ * @cond LOCAL
+ */
 
 static Ecore_WinCE_Window *_ecore_wince_mouse_down_last_window = NULL;
 static Ecore_WinCE_Window *_ecore_wince_mouse_down_last_last_window = NULL;
@@ -29,561 +30,6 @@ static long                _ecore_wince_mouse_down_last_last_time = 0;
 static int                 _ecore_wince_mouse_down_did_triple = 0;
 static int                 _ecore_wince_mouse_up_count = 0;
 
-
-static void _ecore_wince_event_free_key_down(void *data,
-                                             void *ev);
-
-static void _ecore_wince_event_free_key_up(void *data,
-                                           void *ev);
-
-static int  _ecore_wince_event_keystroke_get(int    key,
-                                             char **keyname,
-                                             char **keysymbol,
-                                             char **keycompose);
-
-static int  _ecore_wince_event_char_get(int    key,
-                                        char **keyname,
-                                        char **keysymbol,
-                                        char **keycompose);
-
-
-/***** Global functions *****/
-
-void
-_ecore_wince_event_handle_key_press(Ecore_WinCE_Callback_Data *msg,
-                                    int                        is_keystroke)
-{
-   Ecore_Event_Key *e;
-
-   INF("key pressed");
-
-   e = (Ecore_Event_Key *)malloc(sizeof(Ecore_Event_Key));
-   if (!e) return;
-
-   if (is_keystroke)
-     {
-        if (!_ecore_wince_event_keystroke_get(LOWORD(msg->window_param),
-                                              (char **)&e->keyname,
-                                              (char **)&e->key,
-                                              (char **)&e->string))
-          {
-             free(e);
-             return;
-          }
-     }
-   else
-     {
-        if (!_ecore_wince_event_char_get(LOWORD(msg->window_param),
-                                         (char **)&e->keyname,
-                                         (char **)&e->key,
-                                         (char **)&e->string))
-          {
-             free(e);
-             return;
-          }
-     }
-
-   e->window = (Ecore_Window)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-   e->timestamp = msg->time;
-
-   _ecore_wince_event_last_time = e->timestamp;
-
-   ecore_event_add(ECORE_EVENT_KEY_DOWN, e, _ecore_wince_event_free_key_down, NULL);
-}
-
-void
-_ecore_wince_event_handle_key_release(Ecore_WinCE_Callback_Data *msg,
-                                      int                        is_keystroke)
-{
-   Ecore_Event_Key *e;
-
-   INF("key released");
-
-   e = (Ecore_Event_Key *)calloc(1, sizeof(Ecore_Event_Key));
-   if (!e) return;
-
-   if (is_keystroke)
-     {
-        if (!_ecore_wince_event_keystroke_get(LOWORD(msg->window_param),
-                                              (char **)&e->keyname,
-                                              (char **)&e->key,
-                                              (char **)&e->string))
-          {
-             free(e);
-             return;
-          }
-     }
-   else
-     {
-        if (!_ecore_wince_event_char_get(LOWORD(msg->window_param),
-                                         (char **)&e->keyname,
-                                         (char **)&e->key,
-                                         (char **)&e->string))
-          {
-             free(e);
-             return;
-          }
-     }
-
-   e->window = (Ecore_Window)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-   e->timestamp = msg->time;
-
-   _ecore_wince_event_last_time = e->timestamp;
-
-   ecore_event_add(ECORE_EVENT_KEY_UP, e, _ecore_wince_event_free_key_up, NULL);
-}
-
-void
-_ecore_wince_event_handle_button_press(Ecore_WinCE_Callback_Data *msg,
-                                       int                        button)
-{
-   Ecore_WinCE_Window *window;
-
-   INF("mouse button pressed");
-
-   window = (Ecore_WinCE_Window *)GetWindowLong(msg->window, GWL_USERDATA);
-
-   {
-      Ecore_Event_Mouse_Move *e;
-
-      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
-      if (!e) return;
-
-      e->window = (Ecore_Window)window;
-      e->x = LOWORD(msg->data_param);
-      e->y = HIWORD(msg->data_param);
-      e->timestamp = msg->time;
-
-      _ecore_wince_event_last_time = e->timestamp;
-      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
-
-      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
-   }
-
-   {
-      Ecore_Event_Mouse_Button *e;
-
-      if (_ecore_wince_mouse_down_did_triple)
-        {
-           _ecore_wince_mouse_down_last_window = NULL;
-           _ecore_wince_mouse_down_last_last_window = NULL;
-           _ecore_wince_mouse_down_last_time = 0;
-           _ecore_wince_mouse_down_last_last_time = 0;
-        }
-
-      e = (Ecore_Event_Mouse_Button *)calloc(1, sizeof(Ecore_Event_Mouse_Button));
-      if (!e) return;
-
-      e->window = (Ecore_Window)window;
-      e->buttons = button;
-      e->x = LOWORD(msg->data_param);
-      e->y = HIWORD(msg->data_param);
-      e->timestamp = msg->time;
-
-      if (((e->timestamp - _ecore_wince_mouse_down_last_time) <= (long)(1000 * _ecore_wince_double_click_time)) &&
-          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window))
-        e->double_click = 1;
-
-      if (((e->timestamp - _ecore_wince_mouse_down_last_last_time) <= (long)(2 * 1000 * _ecore_wince_double_click_time)) &&
-          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window) &&
-          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_last_window))
-        {
-           e->triple_click = 1;
-           _ecore_wince_mouse_down_did_triple = 1;
-        }
-      else
-        _ecore_wince_mouse_down_did_triple = 0;
-
-      if (!e->double_click && !e->triple_click)
-        _ecore_wince_mouse_up_count = 0;
-
-      _ecore_wince_event_last_time = e->timestamp;
-      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
-
-      if (!_ecore_wince_mouse_down_did_triple)
-        {
-           _ecore_wince_mouse_down_last_last_window = _ecore_wince_mouse_down_last_window;
-           _ecore_wince_mouse_down_last_window = (Ecore_WinCE_Window *)e->window;
-           _ecore_wince_mouse_down_last_last_time = _ecore_wince_mouse_down_last_time;
-           _ecore_wince_mouse_down_last_time = e->timestamp;
-        }
-
-      ecore_event_add(ECORE_EVENT_MOUSE_BUTTON_DOWN, e, NULL, NULL);
-   }
-}
-
-void
-_ecore_wince_event_handle_button_release(Ecore_WinCE_Callback_Data *msg,
-                                         int                        button)
-{
-   Ecore_WinCE_Window *window;
-
-   INF("mouse button released");
-
-   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-
-   {
-      Ecore_Event_Mouse_Move *e;
-
-      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
-      if (!e) return;
-
-      e->window = (Ecore_Window)window;
-      e->x = LOWORD(msg->data_param);
-      e->y = HIWORD(msg->data_param);
-      e->timestamp = msg->time;
-
-      _ecore_wince_event_last_time = e->timestamp;
-      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
-
-      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
-   }
-
-   {
-      Ecore_Event_Mouse_Button *e;
-
-      e = (Ecore_Event_Mouse_Button *)calloc(1, sizeof(Ecore_Event_Mouse_Button));
-      if (!e) return;
-
-      e->window = (Ecore_Window)window;
-      e->buttons = button;
-      e->x = LOWORD(msg->data_param);
-      e->y = HIWORD(msg->data_param);
-      e->timestamp = msg->time;
-
-      _ecore_wince_mouse_up_count++;
-
-      if ((_ecore_wince_mouse_up_count >= 2) &&
-          ((e->timestamp - _ecore_wince_mouse_down_last_time) <= (long)(1000 * _ecore_wince_double_click_time)) &&
-          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window))
-        e->double_click = 1;
-
-      if ((_ecore_wince_mouse_up_count >= 3) &&
-          ((e->timestamp - _ecore_wince_mouse_down_last_last_time) <= (long)(2 * 1000 * _ecore_wince_double_click_time)) &&
-          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window) &&
-          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_last_window))
-        e->triple_click = 1;
-
-      _ecore_wince_event_last_time = e->timestamp;
-      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
-
-      ecore_event_add(ECORE_EVENT_MOUSE_BUTTON_UP, e, NULL, NULL);
-   }
-}
-
-void
-_ecore_wince_event_handle_motion_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_Event_Mouse_Move *e;
-
-   INF("mouse moved");
-
-   e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
-   if (!e) return;
-
-   e->window = (Ecore_Window)GetWindowLong(msg->window, GWL_USERDATA);
-   e->x = LOWORD(msg->data_param);
-   e->y = HIWORD(msg->data_param);
-   e->timestamp = msg->time;
-
-   ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_enter_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Window *window;
-
-   INF("mouse in");
-
-   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-
-   {
-      Ecore_Event_Mouse_Move *e;
-
-      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
-      if (!e) return;
-
-      e->window = (Ecore_Window)window;
-      e->x = msg->x;
-      e->y = msg->y;
-      e->timestamp = msg->time;
-
-      _ecore_wince_event_last_time = e->timestamp;
-      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
-
-      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
-   }
-
-   {
-      Ecore_WinCE_Event_Mouse_In *e;
-
-      e = (Ecore_WinCE_Event_Mouse_In *)calloc(1, sizeof(Ecore_WinCE_Event_Mouse_In));
-      if (!e) return;
-
-      e->window = window;
-      e->x = msg->x;
-      e->y = msg->y;
-      e->time = msg->time;
-
-      _ecore_wince_event_last_time = e->time;
-
-      ecore_event_add(ECORE_WINCE_EVENT_MOUSE_IN, e, NULL, NULL);
-   }
-}
-
-void
-_ecore_wince_event_handle_leave_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Window *window;
-
-   INF("mouse out");
-
-   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-
-   {
-      Ecore_Event_Mouse_Move *e;
-
-      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
-      if (!e) return;
-
-      e->window = (Ecore_Window)window;
-      e->x = msg->x;
-      e->y = msg->y;
-      e->timestamp = msg->time;
-
-      _ecore_wince_event_last_time = e->timestamp;
-      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
-
-      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
-   }
-
-   {
-      Ecore_WinCE_Event_Mouse_Out *e;
-
-      e = (Ecore_WinCE_Event_Mouse_Out *)calloc(1, sizeof(Ecore_WinCE_Event_Mouse_Out));
-      if (!e) return;
-
-      e->window = window;
-      e->x = msg->x;
-      e->y = msg->y;
-      e->time = msg->time;
-
-      _ecore_wince_event_last_time = e->time;
-
-      ecore_event_add(ECORE_WINCE_EVENT_MOUSE_OUT, e, NULL, NULL);
-   }
-}
-
-void
-_ecore_wince_event_handle_focus_in(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Focus_In *e;
-   struct _Ecore_WinCE_Window        *window;
-
-   INF("focus in");
-
-   e = (Ecore_WinCE_Event_Window_Focus_In *)calloc(1, sizeof(Ecore_WinCE_Event_Window_Focus_In));
-   if (!e) return;
-
-   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   if (window->resume)
-     window->resume(window->backend);
-
-   e->window = window;
-
-   e->time = _ecore_wince_event_last_time;
-   _ecore_wince_event_last_time = e->time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_FOCUS_IN, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_focus_out(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Focus_Out *e;
-   struct _Ecore_WinCE_Window         *window;
-
-   INF("focus out");
-
-   e = (Ecore_WinCE_Event_Window_Focus_Out *)calloc(1, sizeof(Ecore_WinCE_Event_Window_Focus_Out));
-   if (!e) return;
-
-   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-   if (window->suspend)
-     window->suspend(window->backend);
-
-   e->window = window;
-
-   e->time = _ecore_wince_event_last_time;
-   _ecore_wince_event_last_time = e->time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_FOCUS_OUT, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_expose(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Damage *e;
-
-   INF("window expose");
-
-   e = (Ecore_WinCE_Event_Window_Damage *)calloc(1, sizeof(Ecore_WinCE_Event_Window_Damage));
-   if (!e) return;
-
-   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   e->x = msg->update.left;
-   e->y = msg->update.top;
-   e->width = msg->update.right - msg->update.left;
-   e->height = msg->update.bottom - msg->update.top;
-   INF("window expose size: %dx%d", e->width, e->height);
-
-   e->time = _ecore_wince_event_last_time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_DAMAGE, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_create_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Create *e;
-
-   INF("window create notify");
-
-   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Create));
-   if (!e) return;
-
-   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   e->time = _ecore_wince_event_last_time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_CREATE, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_destroy_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Destroy *e;
-
-   INF("window destroy notify");
-
-   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Destroy));
-   if (!e) return;
-
-   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   e->time = _ecore_wince_event_last_time;
-/*    if (e->window == _ecore_wince_event_last_window) _ecore_wince_event_last_window = NULL; */
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_DESTROY, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_map_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Show *e;
-
-   INF("window map notify");
-
-   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Show));
-   if (!e) return;
-
-   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   e->time = _ecore_wince_event_last_time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_SHOW, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_unmap_notify(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Hide *e;
-
-   INF("window unmap notify");
-
-   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Hide));
-   if (!e) return;
-
-   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   e->time = _ecore_wince_event_last_time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_HIDE, e, NULL, NULL);
-}
-
-void
-_ecore_wince_event_handle_delete_request(Ecore_WinCE_Callback_Data *msg)
-{
-   Ecore_WinCE_Event_Window_Delete_Request *e;
-
-   INF("window delete request");
-
-   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Delete_Request));
-   if (!e) return;
-
-   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
-   if (!e->window)
-     {
-        free(e);
-        return;
-     }
-
-   e->time = _ecore_wince_event_last_time;
-
-   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_DELETE_REQUEST, e, NULL, NULL);
-}
-
-
-/***** Private functions definitions *****/
-
 static void
 _ecore_wince_event_free_key_down(void *data __UNUSED__,
                                  void *ev)
@@ -677,6 +123,11 @@ _ecore_wince_event_keystroke_get(int    key,
        ks = "Delete";
        kc = "Delete";
        break;
+     case VK_SPACE:
+       kn = "space";
+       ks = "space";
+       kc = "space";
+       break;
      case VK_F1:
        kn = "F1";
        ks = "F1";
@@ -883,6 +334,11 @@ _ecore_wince_event_char_get(int    key,
        strncpy(ks, "Escape", 32);
        strncpy(kc, "Escape", 32);
        break;
+     case VK_SPACE:
+       strncpy(kn, "space", 32);
+       strncpy(ks, "space", 32);
+       strncpy(kc, "space", 32);
+       break;
      default:
        /* displayable characters */
        printf (" * key : %d\n", key);
@@ -915,3 +371,558 @@ _ecore_wince_event_char_get(int    key,
 
    return 1;
 }
+
+/**
+ * @endcond
+ */
+
+
+/*============================================================================*
+ *                                 Global                                     *
+ *============================================================================*/
+
+void
+_ecore_wince_event_handle_key_press(Ecore_WinCE_Callback_Data *msg,
+                                    int                        is_keystroke)
+{
+   Ecore_Event_Key *e;
+
+   INF("key pressed");
+
+   e = (Ecore_Event_Key *)malloc(sizeof(Ecore_Event_Key));
+   if (!e) return;
+
+   if (is_keystroke)
+     {
+        if (!_ecore_wince_event_keystroke_get(LOWORD(msg->window_param),
+                                              (char **)&e->keyname,
+                                              (char **)&e->key,
+                                              (char **)&e->string))
+          {
+             free(e);
+             return;
+          }
+     }
+   else
+     {
+        if (!_ecore_wince_event_char_get(LOWORD(msg->window_param),
+                                         (char **)&e->keyname,
+                                         (char **)&e->key,
+                                         (char **)&e->string))
+          {
+             free(e);
+             return;
+          }
+     }
+
+   e->window = (Ecore_Window)GetWindowLong(msg->window, GWL_USERDATA);
+   e->event_window = e->window;
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+   e->timestamp = msg->time;
+
+   _ecore_wince_event_last_time = e->timestamp;
+
+   ecore_event_add(ECORE_EVENT_KEY_DOWN, e, _ecore_wince_event_free_key_down, NULL);
+}
+
+void
+_ecore_wince_event_handle_key_release(Ecore_WinCE_Callback_Data *msg,
+                                      int                        is_keystroke)
+{
+   Ecore_Event_Key *e;
+
+   INF("key released");
+
+   e = (Ecore_Event_Key *)calloc(1, sizeof(Ecore_Event_Key));
+   if (!e) return;
+
+   if (is_keystroke)
+     {
+        if (!_ecore_wince_event_keystroke_get(LOWORD(msg->window_param),
+                                              (char **)&e->keyname,
+                                              (char **)&e->key,
+                                              (char **)&e->string))
+          {
+             free(e);
+             return;
+          }
+     }
+   else
+     {
+        if (!_ecore_wince_event_char_get(LOWORD(msg->window_param),
+                                         (char **)&e->keyname,
+                                         (char **)&e->key,
+                                         (char **)&e->string))
+          {
+             free(e);
+             return;
+          }
+     }
+
+   e->window = (Ecore_Window)GetWindowLong(msg->window, GWL_USERDATA);
+   e->event_window = e->window;
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+   e->timestamp = msg->time;
+
+   _ecore_wince_event_last_time = e->timestamp;
+
+   ecore_event_add(ECORE_EVENT_KEY_UP, e, _ecore_wince_event_free_key_up, NULL);
+}
+
+void
+_ecore_wince_event_handle_button_press(Ecore_WinCE_Callback_Data *msg,
+                                       int                        button)
+{
+   Ecore_WinCE_Window *window;
+
+   INF("mouse button pressed");
+
+   window = (Ecore_WinCE_Window *)GetWindowLong(msg->window, GWL_USERDATA);
+
+   {
+      Ecore_Event_Mouse_Move *e;
+
+      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
+      if (!e) return;
+
+      e->window = (Ecore_Window)window;
+      e->event_window = e->window;
+      e->x = LOWORD(msg->data_param);
+      e->y = HIWORD(msg->data_param);
+      e->timestamp = msg->time;
+
+      _ecore_wince_event_last_time = e->timestamp;
+      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
+
+      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
+   }
+
+   {
+      Ecore_Event_Mouse_Button *e;
+
+      if (_ecore_wince_mouse_down_did_triple)
+        {
+           _ecore_wince_mouse_down_last_window = NULL;
+           _ecore_wince_mouse_down_last_last_window = NULL;
+           _ecore_wince_mouse_down_last_time = 0;
+           _ecore_wince_mouse_down_last_last_time = 0;
+        }
+
+      e = (Ecore_Event_Mouse_Button *)calloc(1, sizeof(Ecore_Event_Mouse_Button));
+      if (!e) return;
+
+      e->window = (Ecore_Window)window;
+      e->event_window = e->window;
+      e->buttons = button;
+      e->x = LOWORD(msg->data_param);
+      e->y = HIWORD(msg->data_param);
+      e->timestamp = msg->time;
+
+      if (((e->timestamp - _ecore_wince_mouse_down_last_time) <= (long)(1000 * _ecore_wince_double_click_time)) &&
+          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window))
+        e->double_click = 1;
+
+      if (((e->timestamp - _ecore_wince_mouse_down_last_last_time) <= (long)(2 * 1000 * _ecore_wince_double_click_time)) &&
+          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window) &&
+          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_last_window))
+        {
+           e->triple_click = 1;
+           _ecore_wince_mouse_down_did_triple = 1;
+        }
+      else
+        _ecore_wince_mouse_down_did_triple = 0;
+
+      if (!e->double_click && !e->triple_click)
+        _ecore_wince_mouse_up_count = 0;
+
+      _ecore_wince_event_last_time = e->timestamp;
+      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
+
+      if (!_ecore_wince_mouse_down_did_triple)
+        {
+           _ecore_wince_mouse_down_last_last_window = _ecore_wince_mouse_down_last_window;
+           _ecore_wince_mouse_down_last_window = (Ecore_WinCE_Window *)e->window;
+           _ecore_wince_mouse_down_last_last_time = _ecore_wince_mouse_down_last_time;
+           _ecore_wince_mouse_down_last_time = e->timestamp;
+        }
+
+      ecore_event_add(ECORE_EVENT_MOUSE_BUTTON_DOWN, e, NULL, NULL);
+   }
+}
+
+void
+_ecore_wince_event_handle_button_release(Ecore_WinCE_Callback_Data *msg,
+                                         int                        button)
+{
+   Ecore_WinCE_Window *window;
+
+   INF("mouse button released");
+
+   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+
+   {
+      Ecore_Event_Mouse_Move *e;
+
+      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
+      if (!e) return;
+
+      e->window = (Ecore_Window)window;
+      e->event_window = e->window;
+      e->x = LOWORD(msg->data_param);
+      e->y = HIWORD(msg->data_param);
+      e->timestamp = msg->time;
+
+      _ecore_wince_event_last_time = e->timestamp;
+      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
+
+      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
+   }
+
+   {
+      Ecore_Event_Mouse_Button *e;
+
+      e = (Ecore_Event_Mouse_Button *)calloc(1, sizeof(Ecore_Event_Mouse_Button));
+      if (!e) return;
+
+      e->window = (Ecore_Window)window;
+      e->event_window = e->window;
+      e->buttons = button;
+      e->x = LOWORD(msg->data_param);
+      e->y = HIWORD(msg->data_param);
+      e->timestamp = msg->time;
+
+      _ecore_wince_mouse_up_count++;
+
+      if ((_ecore_wince_mouse_up_count >= 2) &&
+          ((e->timestamp - _ecore_wince_mouse_down_last_time) <= (long)(1000 * _ecore_wince_double_click_time)) &&
+          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window))
+        e->double_click = 1;
+
+      if ((_ecore_wince_mouse_up_count >= 3) &&
+          ((e->timestamp - _ecore_wince_mouse_down_last_last_time) <= (long)(2 * 1000 * _ecore_wince_double_click_time)) &&
+          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_window) &&
+          (e->window == (Ecore_Window)_ecore_wince_mouse_down_last_last_window))
+        e->triple_click = 1;
+
+      _ecore_wince_event_last_time = e->timestamp;
+      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
+
+      ecore_event_add(ECORE_EVENT_MOUSE_BUTTON_UP, e, NULL, NULL);
+   }
+}
+
+void
+_ecore_wince_event_handle_motion_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_Event_Mouse_Move *e;
+
+   INF("mouse moved");
+
+   e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
+   if (!e) return;
+
+   e->window = (Ecore_Window)GetWindowLong(msg->window, GWL_USERDATA);
+   e->event_window = e->window;
+   e->x = LOWORD(msg->data_param);
+   e->y = HIWORD(msg->data_param);
+   e->timestamp = msg->time;
+
+   ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_enter_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Window *window;
+
+   INF("mouse in");
+
+   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+
+   {
+      Ecore_Event_Mouse_Move *e;
+
+      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
+      if (!e) return;
+
+      e->window = (Ecore_Window)window;
+      e->event_window = e->window;
+      e->x = msg->x;
+      e->y = msg->y;
+      e->timestamp = msg->time;
+
+      _ecore_wince_event_last_time = e->timestamp;
+      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
+
+      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
+   }
+
+   {
+      Ecore_WinCE_Event_Mouse_In *e;
+
+      e = (Ecore_WinCE_Event_Mouse_In *)calloc(1, sizeof(Ecore_WinCE_Event_Mouse_In));
+      if (!e) return;
+
+      e->window = window;
+      e->x = msg->x;
+      e->y = msg->y;
+      e->time = msg->time;
+
+      _ecore_wince_event_last_time = e->time;
+
+      ecore_event_add(ECORE_WINCE_EVENT_MOUSE_IN, e, NULL, NULL);
+   }
+}
+
+void
+_ecore_wince_event_handle_leave_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Window *window;
+
+   INF("mouse out");
+
+   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+
+   {
+      Ecore_Event_Mouse_Move *e;
+
+      e = (Ecore_Event_Mouse_Move *)calloc(1, sizeof(Ecore_Event_Mouse_Move));
+      if (!e) return;
+
+      e->window = (Ecore_Window)window;
+      e->event_window = e->window;
+      e->x = msg->x;
+      e->y = msg->y;
+      e->timestamp = msg->time;
+
+      _ecore_wince_event_last_time = e->timestamp;
+      _ecore_wince_event_last_window = (Ecore_WinCE_Window *)e->window;
+
+      ecore_event_add(ECORE_EVENT_MOUSE_MOVE, e, NULL, NULL);
+   }
+
+   {
+      Ecore_WinCE_Event_Mouse_Out *e;
+
+      e = (Ecore_WinCE_Event_Mouse_Out *)calloc(1, sizeof(Ecore_WinCE_Event_Mouse_Out));
+      if (!e) return;
+
+      e->window = window;
+      e->x = msg->x;
+      e->y = msg->y;
+      e->time = msg->time;
+
+      _ecore_wince_event_last_time = e->time;
+
+      ecore_event_add(ECORE_WINCE_EVENT_MOUSE_OUT, e, NULL, NULL);
+   }
+}
+
+void
+_ecore_wince_event_handle_focus_in(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Focus_In *e;
+   struct _Ecore_WinCE_Window        *window;
+
+   INF("focus in");
+
+   e = (Ecore_WinCE_Event_Window_Focus_In *)calloc(1, sizeof(Ecore_WinCE_Event_Window_Focus_In));
+   if (!e) return;
+
+   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   if (window->resume_cb)
+     window->resume_cb(window->backend);
+
+   e->window = window;
+
+   e->time = _ecore_wince_event_last_time;
+   _ecore_wince_event_last_time = e->time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_FOCUS_IN, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_focus_out(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Focus_Out *e;
+   struct _Ecore_WinCE_Window         *window;
+
+   INF("focus out");
+
+   e = (Ecore_WinCE_Event_Window_Focus_Out *)calloc(1, sizeof(Ecore_WinCE_Event_Window_Focus_Out));
+   if (!e) return;
+
+   window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+   if (window->suspend_cb)
+     window->suspend_cb(window->backend);
+
+   e->window = window;
+
+   e->time = _ecore_wince_event_last_time;
+   _ecore_wince_event_last_time = e->time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_FOCUS_OUT, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_expose(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Damage *e;
+
+   INF("window expose");
+
+   e = (Ecore_WinCE_Event_Window_Damage *)calloc(1, sizeof(Ecore_WinCE_Event_Window_Damage));
+   if (!e) return;
+
+   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   e->x = msg->update.left;
+   e->y = msg->update.top;
+   e->width = msg->update.right - msg->update.left;
+   e->height = msg->update.bottom - msg->update.top;
+   INF("window expose size: %dx%d", e->width, e->height);
+
+   e->time = _ecore_wince_event_last_time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_DAMAGE, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_create_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Create *e;
+
+   INF("window create notify");
+
+   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Create));
+   if (!e) return;
+
+   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   e->time = _ecore_wince_event_last_time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_CREATE, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_destroy_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Destroy *e;
+
+   INF("window destroy notify");
+
+   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Destroy));
+   if (!e) return;
+
+   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   e->time = _ecore_wince_event_last_time;
+/*    if (e->window == _ecore_wince_event_last_window) _ecore_wince_event_last_window = NULL; */
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_DESTROY, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_map_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Show *e;
+
+   INF("window map notify");
+
+   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Show));
+   if (!e) return;
+
+   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   e->time = _ecore_wince_event_last_time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_SHOW, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_unmap_notify(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Hide *e;
+
+   INF("window unmap notify");
+
+   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Hide));
+   if (!e) return;
+
+   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   e->time = _ecore_wince_event_last_time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_HIDE, e, NULL, NULL);
+}
+
+void
+_ecore_wince_event_handle_delete_request(Ecore_WinCE_Callback_Data *msg)
+{
+   Ecore_WinCE_Event_Window_Delete_Request *e;
+
+   INF("window delete request");
+
+   e = calloc(1, sizeof(Ecore_WinCE_Event_Window_Delete_Request));
+   if (!e) return;
+
+   e->window = (void *)GetWindowLong(msg->window, GWL_USERDATA);
+   if (!e->window)
+     {
+        free(e);
+        return;
+     }
+
+   e->time = _ecore_wince_event_last_time;
+
+   ecore_event_add(ECORE_WINCE_EVENT_WINDOW_DELETE_REQUEST, e, NULL, NULL);
+}
+
+/*============================================================================*
+ *                                   API                                      *
+ *============================================================================*/
+
