@@ -1,18 +1,12 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #include "ecore_xcb_private.h"
 #include <xcb/xcb.h>
 
-
 /**
  * @defgroup Ecore_X_Drawable_Group X Drawable Functions
  *
  * Functions that operate on drawables.
  */
 
-
 /**
  * Sends the GetGeometry request.
  * @param drawable Drawable whose characteristics are sought.
@@ -25,8 +19,7 @@ ecore_x_drawable_geometry_get_prefetch(Ecore_X_Drawable drawable)
 
    cookie = xcb_get_geometry_unchecked(_ecore_xcb_conn, drawable);
    _ecore_xcb_cookie_cache(cookie.sequence);
-}
-
+} /* ecore_x_drawable_geometry_get_prefetch */
 
 /**
  * Gets the reply of the GetGeometry request sent by ecore_x_atom_get_prefetch().
@@ -41,8 +34,7 @@ ecore_x_drawable_geometry_get_fetch(void)
    cookie.sequence = _ecore_xcb_cookie_get();
    reply = xcb_get_geometry_reply(_ecore_xcb_conn, cookie, NULL);
    _ecore_xcb_reply_cache(reply);
-}
-
+} /* ecore_x_drawable_geometry_get_fetch */
 
 /**
  * Retrieves the geometry of the given drawable.
@@ -59,29 +51,43 @@ ecore_x_drawable_geometry_get_fetch(void)
  */
 EAPI void
 ecore_x_drawable_geometry_get(Ecore_X_Drawable drawable __UNUSED__,
-                              int             *x,
-                              int             *y,
-                              int             *width,
-                              int             *height)
+                              int                      *x,
+                              int                      *y,
+                              int                      *width,
+                              int                      *height)
 {
    xcb_get_geometry_reply_t *reply;
 
    reply = _ecore_xcb_reply_get();
    if (!reply)
      {
-        if (x) *x = 0;
-        if (y) *y = 0;
-        if (width) *width = 0;
-        if (height) *height = 0;
+        if (x)
+           *x = 0;
+
+        if (y)
+           *y = 0;
+
+        if (width)
+           *width = 0;
+
+        if (height)
+           *height = 0;
+
         return;
      }
 
-   if (x) *x = reply->x;
-   if (y) *y = reply->y;
-   if (width) *width = reply->width;
-   if (height) *height = reply->height;
-}
+   if (x)
+      *x = reply->x;
 
+   if (y)
+      *y = reply->y;
+
+   if (width)
+      *width = reply->width;
+
+   if (height)
+      *height = reply->height;
+} /* ecore_x_drawable_geometry_get */
 
 /**
  * Retrieves the width of the border of the given drawable.
@@ -100,11 +106,10 @@ ecore_x_drawable_border_width_get(Ecore_X_Drawable drawable __UNUSED__)
 
    reply = _ecore_xcb_reply_get();
    if (!reply)
-     return 0;
+      return 0;
 
    return reply->border_width;
-}
-
+} /* ecore_x_drawable_border_width_get */
 
 /**
  * Retrieves the depth of the given drawable.
@@ -123,10 +128,10 @@ ecore_x_drawable_depth_get(Ecore_X_Drawable drawable __UNUSED__)
 
    reply = _ecore_xcb_reply_get();
    if (!reply)
-     return 0;
+      return 0;
 
    return reply->depth;
-}
+} /* ecore_x_drawable_depth_get */
 
 /**
  * Fill the specified rectangle on a drawable.
@@ -147,4 +152,5 @@ ecore_x_drawable_rectangle_fill(Ecore_X_Drawable d, Ecore_X_GC gc, int x, int y,
    rectangle.width = width;
    rectangle.height = height;
    xcb_poly_fill_rectangle(_ecore_xcb_conn, d, gc, 1, &rectangle);
-}
+} /* ecore_x_drawable_rectangle_fill */
+
