@@ -1,17 +1,11 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #include "ecore_xcb_private.h"
 
-
 /**
  * @defgroup Ecore_X_Pixmap_Group X Pixmap Functions
  *
  * Functions that operate on pixmaps.
  */
 
-
 /**
  * Creates a new pixmap.
  * @param   win Window used to determine which screen of the display the
@@ -32,15 +26,17 @@ ecore_x_pixmap_new(Ecore_X_Window win,
 {
    Ecore_X_Pixmap pmap;
 
-   if (win == 0) win = ((xcb_screen_t *)_ecore_xcb_screen)->root;
-   if (dep == 0) dep = ((xcb_screen_t *)_ecore_xcb_screen)->root_depth;
+   if (win == 0)
+      win = ((xcb_screen_t *)_ecore_xcb_screen)->root;
+
+   if (dep == 0)
+      dep = ((xcb_screen_t *)_ecore_xcb_screen)->root_depth;
 
    pmap = xcb_generate_id(_ecore_xcb_conn);
    xcb_create_pixmap(_ecore_xcb_conn, dep, pmap, win, w, h);
 
    return pmap;
-}
-
+} /* ecore_x_pixmap_new */
 
 /**
  * Deletes the reference to the given pixmap.
@@ -55,8 +51,7 @@ EAPI void
 ecore_x_pixmap_free(Ecore_X_Pixmap pmap)
 {
    xcb_free_pixmap(_ecore_xcb_conn, pmap);
-}
-
+} /* ecore_x_pixmap_free */
 
 /**
  * Pastes a rectangular area of the given pixmap onto the given drawable.
@@ -75,17 +70,16 @@ ecore_x_pixmap_free(Ecore_X_Pixmap pmap)
 EAPI void
 ecore_x_pixmap_paste(Ecore_X_Pixmap   pmap,
                      Ecore_X_Drawable dest,
-		     Ecore_X_GC       gc,
+                     Ecore_X_GC       gc,
                      int              sx,
                      int              sy,
-		     int              w,
+                     int              w,
                      int              h,
                      int              dx,
                      int              dy)
 {
    xcb_copy_area(_ecore_xcb_conn, pmap, dest, gc, sx, sy, dx, dy, w, h);
-}
-
+} /* ecore_x_pixmap_paste */
 
 /**
  * Retrieves the size of the given pixmap.
@@ -101,8 +95,7 @@ ecore_x_pixmap_geometry_get(Ecore_X_Pixmap pmap, int *x, int *y, int *w, int *h)
 {
    if (pmap)
       ecore_x_drawable_geometry_get(pmap, x, y, w, h);
-}
-
+} /* ecore_x_pixmap_geometry_get */
 
 /**
  * Retrieves the depth of the given pixmap.
@@ -114,4 +107,5 @@ EAPI int
 ecore_x_pixmap_depth_get(Ecore_X_Pixmap pmap)
 {
    return ecore_x_drawable_depth_get(pmap);
-}
+} /* ecore_x_pixmap_depth_get */
+
