@@ -1,13 +1,8 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #include <stdlib.h>
 
 #include <Eina.h>
 
-
-/* 
+/*
  * FIXME:
  * - in ecore_xcb_cookie_cache, should provide better error management
  *   when memory allocation fails
@@ -19,37 +14,36 @@
  *   but its code is commented.
  */
 
-static Eina_List  *_ecore_xcb_cookies = NULL;
-static void       *_ecore_xcb_reply = NULL;
+static Eina_List *_ecore_xcb_cookies = NULL;
+static void *_ecore_xcb_reply = NULL;
 
-typedef struct _Ecore_Xcb_Data Ecore_Xcb_Data;
+typedef struct _Ecore_Xcb_Data   Ecore_Xcb_Data;
 
 struct _Ecore_Xcb_Data
 {
-  unsigned int         cookie;
+   unsigned int cookie;
 };
 
-
 int
 _ecore_x_reply_init ()
 {
    return 1;
-}
+} /* _ecore_x_reply_init */
 
 void
 _ecore_x_reply_shutdown ()
 {
-  Ecore_Xcb_Data *data;
+   Ecore_Xcb_Data *data;
 
-  if (_ecore_xcb_reply)
-    free(_ecore_xcb_reply);
+   if (_ecore_xcb_reply)
+      free(_ecore_xcb_reply);
 
    if (!_ecore_xcb_cookies)
-     return;
+      return;
 
    EINA_LIST_FREE(_ecore_xcb_cookies, data)
-     free(data);
-}
+   free(data);
+} /* _ecore_x_reply_shutdown */
 
 void
 _ecore_xcb_cookie_cache (unsigned int cookie)
@@ -57,11 +51,11 @@ _ecore_xcb_cookie_cache (unsigned int cookie)
    Ecore_Xcb_Data *data;
 
    if (!_ecore_xcb_cookies)
-     return;
+      return;
 
    data = (Ecore_Xcb_Data *)malloc(sizeof(Ecore_Xcb_Data));
    if (!data)
-     return;
+      return;
 
    data->cookie = cookie;
 
@@ -71,40 +65,42 @@ _ecore_xcb_cookie_cache (unsigned int cookie)
         free(data);
         return;
      }
-}
+} /* _ecore_xcb_cookie_cache */
 
 unsigned int
 _ecore_xcb_cookie_get (void)
 {
    Ecore_Xcb_Data *data;
-   unsigned int    cookie;
+   unsigned int cookie;
 
    if (!_ecore_xcb_cookies)
-     return 0;
+      return 0;
 
    data = eina_list_data_get(_ecore_xcb_cookies);
-   if (!data) return 0;
+   if (!data)
+      return 0;
 
    _ecore_xcb_cookies = eina_list_remove_list(_ecore_xcb_cookies, _ecore_xcb_cookies);
-        cookie = data->cookie;
-        free(data);
+   cookie = data->cookie;
+   free(data);
 
-        return cookie;
-}
+   return cookie;
+} /* _ecore_xcb_cookie_get */
 
 void
 _ecore_xcb_reply_cache (void *reply)
 {
    if (_ecore_xcb_reply)
-     free(_ecore_xcb_reply);
+      free(_ecore_xcb_reply);
+
    _ecore_xcb_reply = reply;
-}
+} /* _ecore_xcb_reply_cache */
 
 void *
 _ecore_xcb_reply_get (void)
 {
    return _ecore_xcb_reply;
-}
+} /* _ecore_xcb_reply_get */
 
 EAPI void
 ecore_xcb_reply_free()
@@ -114,4 +110,5 @@ ecore_xcb_reply_free()
 /*        free(_ecore_xcb_reply); */
 /*        _ecore_xcb_reply = NULL; */
 /*     } */
-}
+} /* ecore_xcb_reply_free */
+
