@@ -1,19 +1,14 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
-#endif
-
+#endif /* ifdef HAVE_CONFIG_H */
 
 #include "ecore_x_private.h"
 #include "Ecore_X.h"
 
-static int _damage_available;
+static Eina_Bool _damage_available = EINA_FALSE;
 #ifdef ECORE_XDAMAGE
 static int _damage_major, _damage_minor;
-#endif
+#endif /* ifdef ECORE_XDAMAGE */
 
 void
 _ecore_x_damage_init(void)
@@ -24,19 +19,20 @@ _ecore_x_damage_init(void)
 
    LOGFN(__FILE__, __LINE__, __FUNCTION__);
    if (XDamageQueryVersion(_ecore_x_disp, &_damage_major, &_damage_minor))
-     _damage_available = 1;
+      _damage_available = EINA_TRUE;
    else
-     _damage_available = 0;
-#else
-   _damage_available = 0;
-#endif
-}
+      _damage_available = EINA_FALSE;
 
-EAPI int
+#else /* ifdef ECORE_XDAMAGE */
+   _damage_available = EINA_FALSE;
+#endif /* ifdef ECORE_XDAMAGE */
+} /* _ecore_x_damage_init */
+
+EAPI Eina_Bool
 ecore_x_damage_query(void)
 {
    return _damage_available;
-}
+} /* ecore_x_damage_query */
 
 EAPI Ecore_X_Damage
 ecore_x_damage_new(Ecore_X_Drawable d, Ecore_X_Damage_Report_Level level)
@@ -47,10 +43,10 @@ ecore_x_damage_new(Ecore_X_Drawable d, Ecore_X_Damage_Report_Level level)
    LOGFN(__FILE__, __LINE__, __FUNCTION__);
    damage = XDamageCreate(_ecore_x_disp, d, level);
    return damage;
-#else
+#else /* ifdef ECORE_XDAMAGE */
    return 0;
-#endif
-}
+#endif /* ifdef ECORE_XDAMAGE */
+} /* ecore_x_damage_new */
 
 EAPI void
 ecore_x_damage_free(Ecore_X_Damage damage)
@@ -58,15 +54,17 @@ ecore_x_damage_free(Ecore_X_Damage damage)
 #ifdef ECORE_XDAMAGE
    LOGFN(__FILE__, __LINE__, __FUNCTION__);
    XDamageDestroy(_ecore_x_disp, damage);
-#endif
-}
+#endif /* ifdef ECORE_XDAMAGE */
+} /* ecore_x_damage_free */
 
 EAPI void
-ecore_x_damage_subtract(Ecore_X_Damage damage, Ecore_X_Region repair, Ecore_X_Region parts)
+ecore_x_damage_subtract(Ecore_X_Damage damage,
+                        Ecore_X_Region repair,
+                        Ecore_X_Region parts)
 {
 #ifdef ECORE_XDAMAGE
    LOGFN(__FILE__, __LINE__, __FUNCTION__);
    XDamageSubtract(_ecore_x_disp, damage, repair, parts);
-#endif
-}
+#endif /* ifdef ECORE_XDAMAGE */
+} /* ecore_x_damage_subtract */
 
